# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTPModuleId(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version_and_microversion': 'str',
        'external_import': 'bool',
        'imported_document_id': 'str',
        'legacy': 'bool',
        'dbimport_string': 'str',
        'imported_element_id': 'str',
        'element_import': 'bool',
        'potentially_valid': 'bool',
        'valid_legacy_version': 'bool',
        'path_version': 'str',
        'imported_version_id': 'str',
        'external_document_with_version_and_element_id': 'BTDocumentWithVersionAndElementId',
        'external_document_with_version': 'BTDocumentWithVersionId',
        'short_descriptor': 'str',
        'path': 'BTPLiteralString',
        'version': 'BTPLiteralString',
        'microversion': 'str',
        'first_child_field': 'int',
        'changeable_child_field_indices': 'list[int]',
        'space_before_path': 'BTPSpace',
        'space_after_path': 'BTPSpace',
        'space_before_version': 'BTPSpace',
        'space_after_version': 'BTPSpace',
        'start_source_location': 'int',
        'end_source_location': 'int',
        'atomic': 'bool',
        'documentation_type': 'str',
        'space_before': 'BTPSpace',
        'space_default': 'bool',
        'space_after': 'BTPSpace',
        'node_id': 'str',
        'child_map_indices': 'list[int]',
        'atomic_child_indices': 'list[int]',
        'node_id_raw': 'BTObjectId',
        'child_list_indices': 'list[int]',
        'type_id': 'int',
        'connection_source': 'BTConnection',
        'export_type_name': 'str',
        'unknown_class': 'bool'
    }

    attribute_map = {
        'version_and_microversion': 'versionAndMicroversion',
        'external_import': 'externalImport',
        'imported_document_id': 'importedDocumentId',
        'legacy': 'legacy',
        'dbimport_string': 'dbimportString',
        'imported_element_id': 'importedElementId',
        'element_import': 'elementImport',
        'potentially_valid': 'potentiallyValid',
        'valid_legacy_version': 'validLegacyVersion',
        'path_version': 'pathVersion',
        'imported_version_id': 'importedVersionId',
        'external_document_with_version_and_element_id': 'externalDocumentWithVersionAndElementId',
        'external_document_with_version': 'externalDocumentWithVersion',
        'short_descriptor': 'shortDescriptor',
        'path': 'path',
        'version': 'version',
        'microversion': 'microversion',
        'first_child_field': 'firstChildField',
        'changeable_child_field_indices': 'changeableChildFieldIndices',
        'space_before_path': 'spaceBeforePath',
        'space_after_path': 'spaceAfterPath',
        'space_before_version': 'spaceBeforeVersion',
        'space_after_version': 'spaceAfterVersion',
        'start_source_location': 'startSourceLocation',
        'end_source_location': 'endSourceLocation',
        'atomic': 'atomic',
        'documentation_type': 'documentationType',
        'space_before': 'spaceBefore',
        'space_default': 'spaceDefault',
        'space_after': 'spaceAfter',
        'node_id': 'nodeId',
        'child_map_indices': 'childMapIndices',
        'atomic_child_indices': 'atomicChildIndices',
        'node_id_raw': 'nodeIdRaw',
        'child_list_indices': 'childListIndices',
        'type_id': 'typeId',
        'connection_source': 'connectionSource',
        'export_type_name': 'exportTypeName',
        'unknown_class': 'unknownClass'
    }

    def __init__(self, version_and_microversion=None, external_import=None, imported_document_id=None, legacy=None, dbimport_string=None, imported_element_id=None, element_import=None, potentially_valid=None, valid_legacy_version=None, path_version=None, imported_version_id=None, external_document_with_version_and_element_id=None, external_document_with_version=None, short_descriptor=None, path=None, version=None, microversion=None, first_child_field=None, changeable_child_field_indices=None, space_before_path=None, space_after_path=None, space_before_version=None, space_after_version=None, start_source_location=None, end_source_location=None, atomic=None, documentation_type=None, space_before=None, space_default=None, space_after=None, node_id=None, child_map_indices=None, atomic_child_indices=None, node_id_raw=None, child_list_indices=None, type_id=None, connection_source=None, export_type_name=None, unknown_class=None):  # noqa: E501
        """BTPModuleId - a model defined in OpenAPI"""  # noqa: E501

        self._version_and_microversion = None
        self._external_import = None
        self._imported_document_id = None
        self._legacy = None
        self._dbimport_string = None
        self._imported_element_id = None
        self._element_import = None
        self._potentially_valid = None
        self._valid_legacy_version = None
        self._path_version = None
        self._imported_version_id = None
        self._external_document_with_version_and_element_id = None
        self._external_document_with_version = None
        self._short_descriptor = None
        self._path = None
        self._version = None
        self._microversion = None
        self._first_child_field = None
        self._changeable_child_field_indices = None
        self._space_before_path = None
        self._space_after_path = None
        self._space_before_version = None
        self._space_after_version = None
        self._start_source_location = None
        self._end_source_location = None
        self._atomic = None
        self._documentation_type = None
        self._space_before = None
        self._space_default = None
        self._space_after = None
        self._node_id = None
        self._child_map_indices = None
        self._atomic_child_indices = None
        self._node_id_raw = None
        self._child_list_indices = None
        self._type_id = None
        self._connection_source = None
        self._export_type_name = None
        self._unknown_class = None
        self.discriminator = None

        if version_and_microversion is not None:
            self.version_and_microversion = version_and_microversion
        if external_import is not None:
            self.external_import = external_import
        if imported_document_id is not None:
            self.imported_document_id = imported_document_id
        if legacy is not None:
            self.legacy = legacy
        if dbimport_string is not None:
            self.dbimport_string = dbimport_string
        if imported_element_id is not None:
            self.imported_element_id = imported_element_id
        if element_import is not None:
            self.element_import = element_import
        if potentially_valid is not None:
            self.potentially_valid = potentially_valid
        if valid_legacy_version is not None:
            self.valid_legacy_version = valid_legacy_version
        if path_version is not None:
            self.path_version = path_version
        if imported_version_id is not None:
            self.imported_version_id = imported_version_id
        if external_document_with_version_and_element_id is not None:
            self.external_document_with_version_and_element_id = external_document_with_version_and_element_id
        if external_document_with_version is not None:
            self.external_document_with_version = external_document_with_version
        if short_descriptor is not None:
            self.short_descriptor = short_descriptor
        if path is not None:
            self.path = path
        if version is not None:
            self.version = version
        if microversion is not None:
            self.microversion = microversion
        if first_child_field is not None:
            self.first_child_field = first_child_field
        if changeable_child_field_indices is not None:
            self.changeable_child_field_indices = changeable_child_field_indices
        if space_before_path is not None:
            self.space_before_path = space_before_path
        if space_after_path is not None:
            self.space_after_path = space_after_path
        if space_before_version is not None:
            self.space_before_version = space_before_version
        if space_after_version is not None:
            self.space_after_version = space_after_version
        if start_source_location is not None:
            self.start_source_location = start_source_location
        if end_source_location is not None:
            self.end_source_location = end_source_location
        if atomic is not None:
            self.atomic = atomic
        if documentation_type is not None:
            self.documentation_type = documentation_type
        if space_before is not None:
            self.space_before = space_before
        if space_default is not None:
            self.space_default = space_default
        if space_after is not None:
            self.space_after = space_after
        if node_id is not None:
            self.node_id = node_id
        if child_map_indices is not None:
            self.child_map_indices = child_map_indices
        if atomic_child_indices is not None:
            self.atomic_child_indices = atomic_child_indices
        if node_id_raw is not None:
            self.node_id_raw = node_id_raw
        if child_list_indices is not None:
            self.child_list_indices = child_list_indices
        if type_id is not None:
            self.type_id = type_id
        if connection_source is not None:
            self.connection_source = connection_source
        if export_type_name is not None:
            self.export_type_name = export_type_name
        if unknown_class is not None:
            self.unknown_class = unknown_class

    @property
    def version_and_microversion(self):
        """Gets the version_and_microversion of this BTPModuleId.  # noqa: E501


        :return: The version_and_microversion of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._version_and_microversion

    @version_and_microversion.setter
    def version_and_microversion(self, version_and_microversion):
        """Sets the version_and_microversion of this BTPModuleId.


        :param version_and_microversion: The version_and_microversion of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._version_and_microversion = version_and_microversion

    @property
    def external_import(self):
        """Gets the external_import of this BTPModuleId.  # noqa: E501


        :return: The external_import of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._external_import

    @external_import.setter
    def external_import(self, external_import):
        """Sets the external_import of this BTPModuleId.


        :param external_import: The external_import of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._external_import = external_import

    @property
    def imported_document_id(self):
        """Gets the imported_document_id of this BTPModuleId.  # noqa: E501


        :return: The imported_document_id of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._imported_document_id

    @imported_document_id.setter
    def imported_document_id(self, imported_document_id):
        """Sets the imported_document_id of this BTPModuleId.


        :param imported_document_id: The imported_document_id of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._imported_document_id = imported_document_id

    @property
    def legacy(self):
        """Gets the legacy of this BTPModuleId.  # noqa: E501


        :return: The legacy of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._legacy

    @legacy.setter
    def legacy(self, legacy):
        """Sets the legacy of this BTPModuleId.


        :param legacy: The legacy of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._legacy = legacy

    @property
    def dbimport_string(self):
        """Gets the dbimport_string of this BTPModuleId.  # noqa: E501


        :return: The dbimport_string of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._dbimport_string

    @dbimport_string.setter
    def dbimport_string(self, dbimport_string):
        """Sets the dbimport_string of this BTPModuleId.


        :param dbimport_string: The dbimport_string of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._dbimport_string = dbimport_string

    @property
    def imported_element_id(self):
        """Gets the imported_element_id of this BTPModuleId.  # noqa: E501


        :return: The imported_element_id of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._imported_element_id

    @imported_element_id.setter
    def imported_element_id(self, imported_element_id):
        """Sets the imported_element_id of this BTPModuleId.


        :param imported_element_id: The imported_element_id of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._imported_element_id = imported_element_id

    @property
    def element_import(self):
        """Gets the element_import of this BTPModuleId.  # noqa: E501


        :return: The element_import of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._element_import

    @element_import.setter
    def element_import(self, element_import):
        """Sets the element_import of this BTPModuleId.


        :param element_import: The element_import of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._element_import = element_import

    @property
    def potentially_valid(self):
        """Gets the potentially_valid of this BTPModuleId.  # noqa: E501


        :return: The potentially_valid of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._potentially_valid

    @potentially_valid.setter
    def potentially_valid(self, potentially_valid):
        """Sets the potentially_valid of this BTPModuleId.


        :param potentially_valid: The potentially_valid of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._potentially_valid = potentially_valid

    @property
    def valid_legacy_version(self):
        """Gets the valid_legacy_version of this BTPModuleId.  # noqa: E501


        :return: The valid_legacy_version of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._valid_legacy_version

    @valid_legacy_version.setter
    def valid_legacy_version(self, valid_legacy_version):
        """Sets the valid_legacy_version of this BTPModuleId.


        :param valid_legacy_version: The valid_legacy_version of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._valid_legacy_version = valid_legacy_version

    @property
    def path_version(self):
        """Gets the path_version of this BTPModuleId.  # noqa: E501


        :return: The path_version of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._path_version

    @path_version.setter
    def path_version(self, path_version):
        """Sets the path_version of this BTPModuleId.


        :param path_version: The path_version of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._path_version = path_version

    @property
    def imported_version_id(self):
        """Gets the imported_version_id of this BTPModuleId.  # noqa: E501


        :return: The imported_version_id of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._imported_version_id

    @imported_version_id.setter
    def imported_version_id(self, imported_version_id):
        """Sets the imported_version_id of this BTPModuleId.


        :param imported_version_id: The imported_version_id of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._imported_version_id = imported_version_id

    @property
    def external_document_with_version_and_element_id(self):
        """Gets the external_document_with_version_and_element_id of this BTPModuleId.  # noqa: E501


        :return: The external_document_with_version_and_element_id of this BTPModuleId.  # noqa: E501
        :rtype: BTDocumentWithVersionAndElementId
        """
        return self._external_document_with_version_and_element_id

    @external_document_with_version_and_element_id.setter
    def external_document_with_version_and_element_id(self, external_document_with_version_and_element_id):
        """Sets the external_document_with_version_and_element_id of this BTPModuleId.


        :param external_document_with_version_and_element_id: The external_document_with_version_and_element_id of this BTPModuleId.  # noqa: E501
        :type: BTDocumentWithVersionAndElementId
        """

        self._external_document_with_version_and_element_id = external_document_with_version_and_element_id

    @property
    def external_document_with_version(self):
        """Gets the external_document_with_version of this BTPModuleId.  # noqa: E501


        :return: The external_document_with_version of this BTPModuleId.  # noqa: E501
        :rtype: BTDocumentWithVersionId
        """
        return self._external_document_with_version

    @external_document_with_version.setter
    def external_document_with_version(self, external_document_with_version):
        """Sets the external_document_with_version of this BTPModuleId.


        :param external_document_with_version: The external_document_with_version of this BTPModuleId.  # noqa: E501
        :type: BTDocumentWithVersionId
        """

        self._external_document_with_version = external_document_with_version

    @property
    def short_descriptor(self):
        """Gets the short_descriptor of this BTPModuleId.  # noqa: E501


        :return: The short_descriptor of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._short_descriptor

    @short_descriptor.setter
    def short_descriptor(self, short_descriptor):
        """Sets the short_descriptor of this BTPModuleId.


        :param short_descriptor: The short_descriptor of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._short_descriptor = short_descriptor

    @property
    def path(self):
        """Gets the path of this BTPModuleId.  # noqa: E501


        :return: The path of this BTPModuleId.  # noqa: E501
        :rtype: BTPLiteralString
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this BTPModuleId.


        :param path: The path of this BTPModuleId.  # noqa: E501
        :type: BTPLiteralString
        """

        self._path = path

    @property
    def version(self):
        """Gets the version of this BTPModuleId.  # noqa: E501


        :return: The version of this BTPModuleId.  # noqa: E501
        :rtype: BTPLiteralString
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BTPModuleId.


        :param version: The version of this BTPModuleId.  # noqa: E501
        :type: BTPLiteralString
        """

        self._version = version

    @property
    def microversion(self):
        """Gets the microversion of this BTPModuleId.  # noqa: E501


        :return: The microversion of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._microversion

    @microversion.setter
    def microversion(self, microversion):
        """Sets the microversion of this BTPModuleId.


        :param microversion: The microversion of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._microversion = microversion

    @property
    def first_child_field(self):
        """Gets the first_child_field of this BTPModuleId.  # noqa: E501


        :return: The first_child_field of this BTPModuleId.  # noqa: E501
        :rtype: int
        """
        return self._first_child_field

    @first_child_field.setter
    def first_child_field(self, first_child_field):
        """Sets the first_child_field of this BTPModuleId.


        :param first_child_field: The first_child_field of this BTPModuleId.  # noqa: E501
        :type: int
        """

        self._first_child_field = first_child_field

    @property
    def changeable_child_field_indices(self):
        """Gets the changeable_child_field_indices of this BTPModuleId.  # noqa: E501


        :return: The changeable_child_field_indices of this BTPModuleId.  # noqa: E501
        :rtype: list[int]
        """
        return self._changeable_child_field_indices

    @changeable_child_field_indices.setter
    def changeable_child_field_indices(self, changeable_child_field_indices):
        """Sets the changeable_child_field_indices of this BTPModuleId.


        :param changeable_child_field_indices: The changeable_child_field_indices of this BTPModuleId.  # noqa: E501
        :type: list[int]
        """

        self._changeable_child_field_indices = changeable_child_field_indices

    @property
    def space_before_path(self):
        """Gets the space_before_path of this BTPModuleId.  # noqa: E501


        :return: The space_before_path of this BTPModuleId.  # noqa: E501
        :rtype: BTPSpace
        """
        return self._space_before_path

    @space_before_path.setter
    def space_before_path(self, space_before_path):
        """Sets the space_before_path of this BTPModuleId.


        :param space_before_path: The space_before_path of this BTPModuleId.  # noqa: E501
        :type: BTPSpace
        """

        self._space_before_path = space_before_path

    @property
    def space_after_path(self):
        """Gets the space_after_path of this BTPModuleId.  # noqa: E501


        :return: The space_after_path of this BTPModuleId.  # noqa: E501
        :rtype: BTPSpace
        """
        return self._space_after_path

    @space_after_path.setter
    def space_after_path(self, space_after_path):
        """Sets the space_after_path of this BTPModuleId.


        :param space_after_path: The space_after_path of this BTPModuleId.  # noqa: E501
        :type: BTPSpace
        """

        self._space_after_path = space_after_path

    @property
    def space_before_version(self):
        """Gets the space_before_version of this BTPModuleId.  # noqa: E501


        :return: The space_before_version of this BTPModuleId.  # noqa: E501
        :rtype: BTPSpace
        """
        return self._space_before_version

    @space_before_version.setter
    def space_before_version(self, space_before_version):
        """Sets the space_before_version of this BTPModuleId.


        :param space_before_version: The space_before_version of this BTPModuleId.  # noqa: E501
        :type: BTPSpace
        """

        self._space_before_version = space_before_version

    @property
    def space_after_version(self):
        """Gets the space_after_version of this BTPModuleId.  # noqa: E501


        :return: The space_after_version of this BTPModuleId.  # noqa: E501
        :rtype: BTPSpace
        """
        return self._space_after_version

    @space_after_version.setter
    def space_after_version(self, space_after_version):
        """Sets the space_after_version of this BTPModuleId.


        :param space_after_version: The space_after_version of this BTPModuleId.  # noqa: E501
        :type: BTPSpace
        """

        self._space_after_version = space_after_version

    @property
    def start_source_location(self):
        """Gets the start_source_location of this BTPModuleId.  # noqa: E501


        :return: The start_source_location of this BTPModuleId.  # noqa: E501
        :rtype: int
        """
        return self._start_source_location

    @start_source_location.setter
    def start_source_location(self, start_source_location):
        """Sets the start_source_location of this BTPModuleId.


        :param start_source_location: The start_source_location of this BTPModuleId.  # noqa: E501
        :type: int
        """

        self._start_source_location = start_source_location

    @property
    def end_source_location(self):
        """Gets the end_source_location of this BTPModuleId.  # noqa: E501


        :return: The end_source_location of this BTPModuleId.  # noqa: E501
        :rtype: int
        """
        return self._end_source_location

    @end_source_location.setter
    def end_source_location(self, end_source_location):
        """Sets the end_source_location of this BTPModuleId.


        :param end_source_location: The end_source_location of this BTPModuleId.  # noqa: E501
        :type: int
        """

        self._end_source_location = end_source_location

    @property
    def atomic(self):
        """Gets the atomic of this BTPModuleId.  # noqa: E501


        :return: The atomic of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._atomic

    @atomic.setter
    def atomic(self, atomic):
        """Sets the atomic of this BTPModuleId.


        :param atomic: The atomic of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._atomic = atomic

    @property
    def documentation_type(self):
        """Gets the documentation_type of this BTPModuleId.  # noqa: E501


        :return: The documentation_type of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._documentation_type

    @documentation_type.setter
    def documentation_type(self, documentation_type):
        """Sets the documentation_type of this BTPModuleId.


        :param documentation_type: The documentation_type of this BTPModuleId.  # noqa: E501
        :type: str
        """
        allowed_values = ["FUNCTION", "PREDICATE", "CONSTANT", "ENUM", "USER_TYPE", "FEATURE_DEFINITION", "FILE_HEADER", "UNDOCUMENTABLE", "UNKNOWN"]  # noqa: E501
        if documentation_type not in allowed_values:
            raise ValueError(
                "Invalid value for `documentation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(documentation_type, allowed_values)
            )

        self._documentation_type = documentation_type

    @property
    def space_before(self):
        """Gets the space_before of this BTPModuleId.  # noqa: E501


        :return: The space_before of this BTPModuleId.  # noqa: E501
        :rtype: BTPSpace
        """
        return self._space_before

    @space_before.setter
    def space_before(self, space_before):
        """Sets the space_before of this BTPModuleId.


        :param space_before: The space_before of this BTPModuleId.  # noqa: E501
        :type: BTPSpace
        """

        self._space_before = space_before

    @property
    def space_default(self):
        """Gets the space_default of this BTPModuleId.  # noqa: E501


        :return: The space_default of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._space_default

    @space_default.setter
    def space_default(self, space_default):
        """Sets the space_default of this BTPModuleId.


        :param space_default: The space_default of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._space_default = space_default

    @property
    def space_after(self):
        """Gets the space_after of this BTPModuleId.  # noqa: E501


        :return: The space_after of this BTPModuleId.  # noqa: E501
        :rtype: BTPSpace
        """
        return self._space_after

    @space_after.setter
    def space_after(self, space_after):
        """Sets the space_after of this BTPModuleId.


        :param space_after: The space_after of this BTPModuleId.  # noqa: E501
        :type: BTPSpace
        """

        self._space_after = space_after

    @property
    def node_id(self):
        """Gets the node_id of this BTPModuleId.  # noqa: E501


        :return: The node_id of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this BTPModuleId.


        :param node_id: The node_id of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._node_id = node_id

    @property
    def child_map_indices(self):
        """Gets the child_map_indices of this BTPModuleId.  # noqa: E501


        :return: The child_map_indices of this BTPModuleId.  # noqa: E501
        :rtype: list[int]
        """
        return self._child_map_indices

    @child_map_indices.setter
    def child_map_indices(self, child_map_indices):
        """Sets the child_map_indices of this BTPModuleId.


        :param child_map_indices: The child_map_indices of this BTPModuleId.  # noqa: E501
        :type: list[int]
        """

        self._child_map_indices = child_map_indices

    @property
    def atomic_child_indices(self):
        """Gets the atomic_child_indices of this BTPModuleId.  # noqa: E501


        :return: The atomic_child_indices of this BTPModuleId.  # noqa: E501
        :rtype: list[int]
        """
        return self._atomic_child_indices

    @atomic_child_indices.setter
    def atomic_child_indices(self, atomic_child_indices):
        """Sets the atomic_child_indices of this BTPModuleId.


        :param atomic_child_indices: The atomic_child_indices of this BTPModuleId.  # noqa: E501
        :type: list[int]
        """

        self._atomic_child_indices = atomic_child_indices

    @property
    def node_id_raw(self):
        """Gets the node_id_raw of this BTPModuleId.  # noqa: E501


        :return: The node_id_raw of this BTPModuleId.  # noqa: E501
        :rtype: BTObjectId
        """
        return self._node_id_raw

    @node_id_raw.setter
    def node_id_raw(self, node_id_raw):
        """Sets the node_id_raw of this BTPModuleId.


        :param node_id_raw: The node_id_raw of this BTPModuleId.  # noqa: E501
        :type: BTObjectId
        """

        self._node_id_raw = node_id_raw

    @property
    def child_list_indices(self):
        """Gets the child_list_indices of this BTPModuleId.  # noqa: E501


        :return: The child_list_indices of this BTPModuleId.  # noqa: E501
        :rtype: list[int]
        """
        return self._child_list_indices

    @child_list_indices.setter
    def child_list_indices(self, child_list_indices):
        """Sets the child_list_indices of this BTPModuleId.


        :param child_list_indices: The child_list_indices of this BTPModuleId.  # noqa: E501
        :type: list[int]
        """

        self._child_list_indices = child_list_indices

    @property
    def type_id(self):
        """Gets the type_id of this BTPModuleId.  # noqa: E501


        :return: The type_id of this BTPModuleId.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this BTPModuleId.


        :param type_id: The type_id of this BTPModuleId.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def connection_source(self):
        """Gets the connection_source of this BTPModuleId.  # noqa: E501


        :return: The connection_source of this BTPModuleId.  # noqa: E501
        :rtype: BTConnection
        """
        return self._connection_source

    @connection_source.setter
    def connection_source(self, connection_source):
        """Sets the connection_source of this BTPModuleId.


        :param connection_source: The connection_source of this BTPModuleId.  # noqa: E501
        :type: BTConnection
        """

        self._connection_source = connection_source

    @property
    def export_type_name(self):
        """Gets the export_type_name of this BTPModuleId.  # noqa: E501


        :return: The export_type_name of this BTPModuleId.  # noqa: E501
        :rtype: str
        """
        return self._export_type_name

    @export_type_name.setter
    def export_type_name(self, export_type_name):
        """Sets the export_type_name of this BTPModuleId.


        :param export_type_name: The export_type_name of this BTPModuleId.  # noqa: E501
        :type: str
        """

        self._export_type_name = export_type_name

    @property
    def unknown_class(self):
        """Gets the unknown_class of this BTPModuleId.  # noqa: E501


        :return: The unknown_class of this BTPModuleId.  # noqa: E501
        :rtype: bool
        """
        return self._unknown_class

    @unknown_class.setter
    def unknown_class(self, unknown_class):
        """Sets the unknown_class of this BTPModuleId.


        :param unknown_class: The unknown_class of this BTPModuleId.  # noqa: E501
        :type: bool
        """

        self._unknown_class = unknown_class

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTPModuleId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



"""For testing all the example programs in the example program directory."""
import os
from pathlib import Path

example_programs=[]
example_programs.append('example_programs/export_step')

def test_example_programs(script_runner):
    example_programs_dir = Path(os.getcwd()) / "example_programs"
    results = []

    for script in example_programs_dir.iterdir():
        if not is_example_program(script):
            continue
        ret = script_runner.run(str(script))
        if not ret.success:
            print("The example program located at {} failed! The stack trace is: \n {}".format(script, ret.stderr))
        assert ret.success
        results.append({"success": ret.success, "name": str(script).split("/")[-1]})

    for res in results:
        print("")

def is_example_program(script):
    result = not script.is_dir() and not str(script).split("/")[-1].startswith('.')



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onshape_client.api_client import ApiClient


class EndpointsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_endpoints(self, **kwargs):  # noqa: E501
        """get_endpoints  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_endpoints(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_endpoints_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_endpoints_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_endpoints_with_http_info(self, **kwargs):  # noqa: E501
        """get_endpoints  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_endpoints_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_endpoints" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/vnd.onshape.v1+json;charset=UTF-8; qs=0.1', 'application/json;charset=UTF-8; qs=0.9'])  # noqa: E501

        # Authentication setting
        auth_settings = ['OAuth2']  # noqa: E501

        return self.api_client.call_api(
            '/api/endpoints', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Message(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'default_title': 'str',
        'default_template': 'str',
        'message_level': 'str'
    }

    attribute_map = {
        'id': 'id',
        'default_title': 'defaultTitle',
        'default_template': 'defaultTemplate',
        'message_level': 'messageLevel'
    }

    def __init__(self, id=None, default_title=None, default_template=None, message_level=None):  # noqa: E501
        """Message - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._default_title = None
        self._default_template = None
        self._message_level = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if default_title is not None:
            self.default_title = default_title
        if default_template is not None:
            self.default_template = default_template
        if message_level is not None:
            self.message_level = message_level

    @property
    def id(self):
        """Gets the id of this Message.  # noqa: E501


        :return: The id of this Message.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Message.


        :param id: The id of this Message.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def default_title(self):
        """Gets the default_title of this Message.  # noqa: E501


        :return: The default_title of this Message.  # noqa: E501
        :rtype: str
        """
        return self._default_title

    @default_title.setter
    def default_title(self, default_title):
        """Sets the default_title of this Message.


        :param default_title: The default_title of this Message.  # noqa: E501
        :type: str
        """

        self._default_title = default_title

    @property
    def default_template(self):
        """Gets the default_template of this Message.  # noqa: E501


        :return: The default_template of this Message.  # noqa: E501
        :rtype: str
        """
        return self._default_template

    @default_template.setter
    def default_template(self, default_template):
        """Sets the default_template of this Message.


        :param default_template: The default_template of this Message.  # noqa: E501
        :type: str
        """

        self._default_template = default_template

    @property
    def message_level(self):
        """Gets the message_level of this Message.  # noqa: E501


        :return: The message_level of this Message.  # noqa: E501
        :rtype: str
        """
        return self._message_level

    @message_level.setter
    def message_level(self, message_level):
        """Sets the message_level of this Message.


        :param message_level: The message_level of this Message.  # noqa: E501
        :type: str
        """
        allowed_values = ["INFO", "WARNING", "ERROR", "MARKETING", "PRODUCT", "IMPORTANT", "ACTION"]  # noqa: E501
        if message_level not in allowed_values:
            raise ValueError(
                "Invalid value for `message_level` ({0}), must be one of {1}"  # noqa: E501
                .format(message_level, allowed_values)
            )

        self._message_level = message_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Message):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class GlobalPermissionInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_reports': 'bool',
        'create_project': 'bool',
        'approve_releases': 'bool',
        'manage_rbac': 'bool',
        'manage_users': 'bool',
        'manage_guest_users': 'bool',
        'create_releases': 'bool',
        'share_for_anonymous_access': 'bool',
        'delete_permanently': 'bool',
        'admin_enterprise': 'bool'
    }

    attribute_map = {
        'access_reports': 'accessReports',
        'create_project': 'createProject',
        'approve_releases': 'approveReleases',
        'manage_rbac': 'manageRbac',
        'manage_users': 'manageUsers',
        'manage_guest_users': 'manageGuestUsers',
        'create_releases': 'createReleases',
        'share_for_anonymous_access': 'shareForAnonymousAccess',
        'delete_permanently': 'deletePermanently',
        'admin_enterprise': 'adminEnterprise'
    }

    def __init__(self, access_reports=None, create_project=None, approve_releases=None, manage_rbac=None, manage_users=None, manage_guest_users=None, create_releases=None, share_for_anonymous_access=None, delete_permanently=None, admin_enterprise=None):  # noqa: E501
        """GlobalPermissionInfo - a model defined in OpenAPI"""  # noqa: E501

        self._access_reports = None
        self._create_project = None
        self._approve_releases = None
        self._manage_rbac = None
        self._manage_users = None
        self._manage_guest_users = None
        self._create_releases = None
        self._share_for_anonymous_access = None
        self._delete_permanently = None
        self._admin_enterprise = None
        self.discriminator = None

        if access_reports is not None:
            self.access_reports = access_reports
        if create_project is not None:
            self.create_project = create_project
        if approve_releases is not None:
            self.approve_releases = approve_releases
        if manage_rbac is not None:
            self.manage_rbac = manage_rbac
        if manage_users is not None:
            self.manage_users = manage_users
        if manage_guest_users is not None:
            self.manage_guest_users = manage_guest_users
        if create_releases is not None:
            self.create_releases = create_releases
        if share_for_anonymous_access is not None:
            self.share_for_anonymous_access = share_for_anonymous_access
        if delete_permanently is not None:
            self.delete_permanently = delete_permanently
        if admin_enterprise is not None:
            self.admin_enterprise = admin_enterprise

    @property
    def access_reports(self):
        """Gets the access_reports of this GlobalPermissionInfo.  # noqa: E501


        :return: The access_reports of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._access_reports

    @access_reports.setter
    def access_reports(self, access_reports):
        """Sets the access_reports of this GlobalPermissionInfo.


        :param access_reports: The access_reports of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._access_reports = access_reports

    @property
    def create_project(self):
        """Gets the create_project of this GlobalPermissionInfo.  # noqa: E501


        :return: The create_project of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._create_project

    @create_project.setter
    def create_project(self, create_project):
        """Sets the create_project of this GlobalPermissionInfo.


        :param create_project: The create_project of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._create_project = create_project

    @property
    def approve_releases(self):
        """Gets the approve_releases of this GlobalPermissionInfo.  # noqa: E501


        :return: The approve_releases of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._approve_releases

    @approve_releases.setter
    def approve_releases(self, approve_releases):
        """Sets the approve_releases of this GlobalPermissionInfo.


        :param approve_releases: The approve_releases of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._approve_releases = approve_releases

    @property
    def manage_rbac(self):
        """Gets the manage_rbac of this GlobalPermissionInfo.  # noqa: E501


        :return: The manage_rbac of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._manage_rbac

    @manage_rbac.setter
    def manage_rbac(self, manage_rbac):
        """Sets the manage_rbac of this GlobalPermissionInfo.


        :param manage_rbac: The manage_rbac of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._manage_rbac = manage_rbac

    @property
    def manage_users(self):
        """Gets the manage_users of this GlobalPermissionInfo.  # noqa: E501


        :return: The manage_users of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._manage_users

    @manage_users.setter
    def manage_users(self, manage_users):
        """Sets the manage_users of this GlobalPermissionInfo.


        :param manage_users: The manage_users of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._manage_users = manage_users

    @property
    def manage_guest_users(self):
        """Gets the manage_guest_users of this GlobalPermissionInfo.  # noqa: E501


        :return: The manage_guest_users of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._manage_guest_users

    @manage_guest_users.setter
    def manage_guest_users(self, manage_guest_users):
        """Sets the manage_guest_users of this GlobalPermissionInfo.


        :param manage_guest_users: The manage_guest_users of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._manage_guest_users = manage_guest_users

    @property
    def create_releases(self):
        """Gets the create_releases of this GlobalPermissionInfo.  # noqa: E501


        :return: The create_releases of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._create_releases

    @create_releases.setter
    def create_releases(self, create_releases):
        """Sets the create_releases of this GlobalPermissionInfo.


        :param create_releases: The create_releases of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._create_releases = create_releases

    @property
    def share_for_anonymous_access(self):
        """Gets the share_for_anonymous_access of this GlobalPermissionInfo.  # noqa: E501


        :return: The share_for_anonymous_access of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._share_for_anonymous_access

    @share_for_anonymous_access.setter
    def share_for_anonymous_access(self, share_for_anonymous_access):
        """Sets the share_for_anonymous_access of this GlobalPermissionInfo.


        :param share_for_anonymous_access: The share_for_anonymous_access of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._share_for_anonymous_access = share_for_anonymous_access

    @property
    def delete_permanently(self):
        """Gets the delete_permanently of this GlobalPermissionInfo.  # noqa: E501


        :return: The delete_permanently of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._delete_permanently

    @delete_permanently.setter
    def delete_permanently(self, delete_permanently):
        """Sets the delete_permanently of this GlobalPermissionInfo.


        :param delete_permanently: The delete_permanently of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._delete_permanently = delete_permanently

    @property
    def admin_enterprise(self):
        """Gets the admin_enterprise of this GlobalPermissionInfo.  # noqa: E501


        :return: The admin_enterprise of this GlobalPermissionInfo.  # noqa: E501
        :rtype: bool
        """
        return self._admin_enterprise

    @admin_enterprise.setter
    def admin_enterprise(self, admin_enterprise):
        """Sets the admin_enterprise of this GlobalPermissionInfo.


        :param admin_enterprise: The admin_enterprise of this GlobalPermissionInfo.  # noqa: E501
        :type: bool
        """

        self._admin_enterprise = admin_enterprise

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GlobalPermissionInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTBetaCapabilityInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'eula': 'str',
        'welcome_html': 'str',
        'user_state': 'int',
        'description': 'str',
        'upgradable': 'bool',
        'user_based': 'bool',
        'self_service_disabled': 'bool',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'eula': 'eula',
        'welcome_html': 'welcomeHTML',
        'user_state': 'userState',
        'description': 'description',
        'upgradable': 'upgradable',
        'user_based': 'userBased',
        'self_service_disabled': 'selfServiceDisabled',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, eula=None, welcome_html=None, user_state=None, description=None, upgradable=None, user_based=None, self_service_disabled=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTBetaCapabilityInfo - a model defined in OpenAPI"""  # noqa: E501

        self._eula = None
        self._welcome_html = None
        self._user_state = None
        self._description = None
        self._upgradable = None
        self._user_based = None
        self._self_service_disabled = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if eula is not None:
            self.eula = eula
        if welcome_html is not None:
            self.welcome_html = welcome_html
        if user_state is not None:
            self.user_state = user_state
        if description is not None:
            self.description = description
        if upgradable is not None:
            self.upgradable = upgradable
        if user_based is not None:
            self.user_based = user_based
        if self_service_disabled is not None:
            self.self_service_disabled = self_service_disabled
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def eula(self):
        """Gets the eula of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The eula of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._eula

    @eula.setter
    def eula(self, eula):
        """Sets the eula of this BTBetaCapabilityInfo.


        :param eula: The eula of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._eula = eula

    @property
    def welcome_html(self):
        """Gets the welcome_html of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The welcome_html of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._welcome_html

    @welcome_html.setter
    def welcome_html(self, welcome_html):
        """Sets the welcome_html of this BTBetaCapabilityInfo.


        :param welcome_html: The welcome_html of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._welcome_html = welcome_html

    @property
    def user_state(self):
        """Gets the user_state of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The user_state of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: int
        """
        return self._user_state

    @user_state.setter
    def user_state(self, user_state):
        """Sets the user_state of this BTBetaCapabilityInfo.


        :param user_state: The user_state of this BTBetaCapabilityInfo.  # noqa: E501
        :type: int
        """

        self._user_state = user_state

    @property
    def description(self):
        """Gets the description of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The description of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTBetaCapabilityInfo.


        :param description: The description of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def upgradable(self):
        """Gets the upgradable of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The upgradable of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: bool
        """
        return self._upgradable

    @upgradable.setter
    def upgradable(self, upgradable):
        """Sets the upgradable of this BTBetaCapabilityInfo.


        :param upgradable: The upgradable of this BTBetaCapabilityInfo.  # noqa: E501
        :type: bool
        """

        self._upgradable = upgradable

    @property
    def user_based(self):
        """Gets the user_based of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The user_based of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: bool
        """
        return self._user_based

    @user_based.setter
    def user_based(self, user_based):
        """Sets the user_based of this BTBetaCapabilityInfo.


        :param user_based: The user_based of this BTBetaCapabilityInfo.  # noqa: E501
        :type: bool
        """

        self._user_based = user_based

    @property
    def self_service_disabled(self):
        """Gets the self_service_disabled of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The self_service_disabled of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: bool
        """
        return self._self_service_disabled

    @self_service_disabled.setter
    def self_service_disabled(self, self_service_disabled):
        """Sets the self_service_disabled of this BTBetaCapabilityInfo.


        :param self_service_disabled: The self_service_disabled of this BTBetaCapabilityInfo.  # noqa: E501
        :type: bool
        """

        self._self_service_disabled = self_service_disabled

    @property
    def name(self):
        """Gets the name of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The name of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTBetaCapabilityInfo.


        :param name: The name of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The id of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTBetaCapabilityInfo.


        :param id: The id of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The href of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTBetaCapabilityInfo.


        :param href: The href of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTBetaCapabilityInfo.  # noqa: E501


        :return: The view_ref of this BTBetaCapabilityInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTBetaCapabilityInfo.


        :param view_ref: The view_ref of this BTBetaCapabilityInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTBetaCapabilityInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ExternalAccount(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'object': 'str',
        'account': 'str',
        'customer': 'str',
        'metadata': 'dict(str, str)',
        'instance_url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'object': 'object',
        'account': 'account',
        'customer': 'customer',
        'metadata': 'metadata',
        'instance_url': 'instanceURL'
    }

    def __init__(self, id=None, object=None, account=None, customer=None, metadata=None, instance_url=None):  # noqa: E501
        """ExternalAccount - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._object = None
        self._account = None
        self._customer = None
        self._metadata = None
        self._instance_url = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if object is not None:
            self.object = object
        if account is not None:
            self.account = account
        if customer is not None:
            self.customer = customer
        if metadata is not None:
            self.metadata = metadata
        if instance_url is not None:
            self.instance_url = instance_url

    @property
    def id(self):
        """Gets the id of this ExternalAccount.  # noqa: E501


        :return: The id of this ExternalAccount.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ExternalAccount.


        :param id: The id of this ExternalAccount.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def object(self):
        """Gets the object of this ExternalAccount.  # noqa: E501


        :return: The object of this ExternalAccount.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this ExternalAccount.


        :param object: The object of this ExternalAccount.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def account(self):
        """Gets the account of this ExternalAccount.  # noqa: E501


        :return: The account of this ExternalAccount.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this ExternalAccount.


        :param account: The account of this ExternalAccount.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def customer(self):
        """Gets the customer of this ExternalAccount.  # noqa: E501


        :return: The customer of this ExternalAccount.  # noqa: E501
        :rtype: str
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this ExternalAccount.


        :param customer: The customer of this ExternalAccount.  # noqa: E501
        :type: str
        """

        self._customer = customer

    @property
    def metadata(self):
        """Gets the metadata of this ExternalAccount.  # noqa: E501


        :return: The metadata of this ExternalAccount.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ExternalAccount.


        :param metadata: The metadata of this ExternalAccount.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def instance_url(self):
        """Gets the instance_url of this ExternalAccount.  # noqa: E501


        :return: The instance_url of this ExternalAccount.  # noqa: E501
        :rtype: str
        """
        return self._instance_url

    @instance_url.setter
    def instance_url(self, instance_url):
        """Sets the instance_url of this ExternalAccount.


        :param instance_url: The instance_url of this ExternalAccount.  # noqa: E501
        :type: str
        """

        self._instance_url = instance_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTWebClientCapabilitiesParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'oes_standard_derivatives_': 'bool',
        'vendor': 'str',
        'depth_texture': 'bool',
        'renderer': 'str',
        'angle_instanced_arrays': 'bool',
        'ext_texture_filter_anisotropic': 'bool',
        'oes_element_index_uint': 'bool',
        'oes_texture_float': 'bool',
        'oes_texture_float_linear': 'bool',
        'oes_texture_half_float': 'bool',
        'oes_texture_half_float_linear': 'bool',
        'oes_vertex_array_object': 'bool',
        'compressed_texture_s3tc': 'bool',
        'draw_buffers': 'bool',
        'has3d_mouse': 'bool',
        'screen_width': 'int',
        'screen_height': 'int',
        'device_pixel_ratio': 'float'
    }

    attribute_map = {
        'oes_standard_derivatives_': 'oesStandardDerivatives_',
        'vendor': 'vendor',
        'depth_texture': 'depthTexture',
        'renderer': 'renderer',
        'angle_instanced_arrays': 'angleInstancedArrays',
        'ext_texture_filter_anisotropic': 'extTextureFilterAnisotropic',
        'oes_element_index_uint': 'oesElementIndexUint',
        'oes_texture_float': 'oesTextureFloat',
        'oes_texture_float_linear': 'oesTextureFloatLinear',
        'oes_texture_half_float': 'oesTextureHalfFloat',
        'oes_texture_half_float_linear': 'oesTextureHalfFloatLinear',
        'oes_vertex_array_object': 'oesVertexArrayObject',
        'compressed_texture_s3tc': 'compressedTextureS3tc',
        'draw_buffers': 'drawBuffers',
        'has3d_mouse': 'has3dMouse',
        'screen_width': 'screenWidth',
        'screen_height': 'screenHeight',
        'device_pixel_ratio': 'devicePixelRatio'
    }

    def __init__(self, oes_standard_derivatives_=None, vendor=None, depth_texture=None, renderer=None, angle_instanced_arrays=None, ext_texture_filter_anisotropic=None, oes_element_index_uint=None, oes_texture_float=None, oes_texture_float_linear=None, oes_texture_half_float=None, oes_texture_half_float_linear=None, oes_vertex_array_object=None, compressed_texture_s3tc=None, draw_buffers=None, has3d_mouse=None, screen_width=None, screen_height=None, device_pixel_ratio=None):  # noqa: E501
        """BTWebClientCapabilitiesParams - a model defined in OpenAPI"""  # noqa: E501

        self._oes_standard_derivatives_ = None
        self._vendor = None
        self._depth_texture = None
        self._renderer = None
        self._angle_instanced_arrays = None
        self._ext_texture_filter_anisotropic = None
        self._oes_element_index_uint = None
        self._oes_texture_float = None
        self._oes_texture_float_linear = None
        self._oes_texture_half_float = None
        self._oes_texture_half_float_linear = None
        self._oes_vertex_array_object = None
        self._compressed_texture_s3tc = None
        self._draw_buffers = None
        self._has3d_mouse = None
        self._screen_width = None
        self._screen_height = None
        self._device_pixel_ratio = None
        self.discriminator = None

        if oes_standard_derivatives_ is not None:
            self.oes_standard_derivatives_ = oes_standard_derivatives_
        if vendor is not None:
            self.vendor = vendor
        if depth_texture is not None:
            self.depth_texture = depth_texture
        if renderer is not None:
            self.renderer = renderer
        if angle_instanced_arrays is not None:
            self.angle_instanced_arrays = angle_instanced_arrays
        if ext_texture_filter_anisotropic is not None:
            self.ext_texture_filter_anisotropic = ext_texture_filter_anisotropic
        if oes_element_index_uint is not None:
            self.oes_element_index_uint = oes_element_index_uint
        if oes_texture_float is not None:
            self.oes_texture_float = oes_texture_float
        if oes_texture_float_linear is not None:
            self.oes_texture_float_linear = oes_texture_float_linear
        if oes_texture_half_float is not None:
            self.oes_texture_half_float = oes_texture_half_float
        if oes_texture_half_float_linear is not None:
            self.oes_texture_half_float_linear = oes_texture_half_float_linear
        if oes_vertex_array_object is not None:
            self.oes_vertex_array_object = oes_vertex_array_object
        if compressed_texture_s3tc is not None:
            self.compressed_texture_s3tc = compressed_texture_s3tc
        if draw_buffers is not None:
            self.draw_buffers = draw_buffers
        if has3d_mouse is not None:
            self.has3d_mouse = has3d_mouse
        if screen_width is not None:
            self.screen_width = screen_width
        if screen_height is not None:
            self.screen_height = screen_height
        if device_pixel_ratio is not None:
            self.device_pixel_ratio = device_pixel_ratio

    @property
    def oes_standard_derivatives_(self):
        """Gets the oes_standard_derivatives_ of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_standard_derivatives_ of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_standard_derivatives_

    @oes_standard_derivatives_.setter
    def oes_standard_derivatives_(self, oes_standard_derivatives_):
        """Sets the oes_standard_derivatives_ of this BTWebClientCapabilitiesParams.


        :param oes_standard_derivatives_: The oes_standard_derivatives_ of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_standard_derivatives_ = oes_standard_derivatives_

    @property
    def vendor(self):
        """Gets the vendor of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The vendor of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this BTWebClientCapabilitiesParams.


        :param vendor: The vendor of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def depth_texture(self):
        """Gets the depth_texture of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The depth_texture of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._depth_texture

    @depth_texture.setter
    def depth_texture(self, depth_texture):
        """Sets the depth_texture of this BTWebClientCapabilitiesParams.


        :param depth_texture: The depth_texture of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._depth_texture = depth_texture

    @property
    def renderer(self):
        """Gets the renderer of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The renderer of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: str
        """
        return self._renderer

    @renderer.setter
    def renderer(self, renderer):
        """Sets the renderer of this BTWebClientCapabilitiesParams.


        :param renderer: The renderer of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: str
        """

        self._renderer = renderer

    @property
    def angle_instanced_arrays(self):
        """Gets the angle_instanced_arrays of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The angle_instanced_arrays of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._angle_instanced_arrays

    @angle_instanced_arrays.setter
    def angle_instanced_arrays(self, angle_instanced_arrays):
        """Sets the angle_instanced_arrays of this BTWebClientCapabilitiesParams.


        :param angle_instanced_arrays: The angle_instanced_arrays of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._angle_instanced_arrays = angle_instanced_arrays

    @property
    def ext_texture_filter_anisotropic(self):
        """Gets the ext_texture_filter_anisotropic of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The ext_texture_filter_anisotropic of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._ext_texture_filter_anisotropic

    @ext_texture_filter_anisotropic.setter
    def ext_texture_filter_anisotropic(self, ext_texture_filter_anisotropic):
        """Sets the ext_texture_filter_anisotropic of this BTWebClientCapabilitiesParams.


        :param ext_texture_filter_anisotropic: The ext_texture_filter_anisotropic of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._ext_texture_filter_anisotropic = ext_texture_filter_anisotropic

    @property
    def oes_element_index_uint(self):
        """Gets the oes_element_index_uint of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_element_index_uint of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_element_index_uint

    @oes_element_index_uint.setter
    def oes_element_index_uint(self, oes_element_index_uint):
        """Sets the oes_element_index_uint of this BTWebClientCapabilitiesParams.


        :param oes_element_index_uint: The oes_element_index_uint of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_element_index_uint = oes_element_index_uint

    @property
    def oes_texture_float(self):
        """Gets the oes_texture_float of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_texture_float of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_texture_float

    @oes_texture_float.setter
    def oes_texture_float(self, oes_texture_float):
        """Sets the oes_texture_float of this BTWebClientCapabilitiesParams.


        :param oes_texture_float: The oes_texture_float of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_texture_float = oes_texture_float

    @property
    def oes_texture_float_linear(self):
        """Gets the oes_texture_float_linear of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_texture_float_linear of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_texture_float_linear

    @oes_texture_float_linear.setter
    def oes_texture_float_linear(self, oes_texture_float_linear):
        """Sets the oes_texture_float_linear of this BTWebClientCapabilitiesParams.


        :param oes_texture_float_linear: The oes_texture_float_linear of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_texture_float_linear = oes_texture_float_linear

    @property
    def oes_texture_half_float(self):
        """Gets the oes_texture_half_float of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_texture_half_float of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_texture_half_float

    @oes_texture_half_float.setter
    def oes_texture_half_float(self, oes_texture_half_float):
        """Sets the oes_texture_half_float of this BTWebClientCapabilitiesParams.


        :param oes_texture_half_float: The oes_texture_half_float of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_texture_half_float = oes_texture_half_float

    @property
    def oes_texture_half_float_linear(self):
        """Gets the oes_texture_half_float_linear of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_texture_half_float_linear of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_texture_half_float_linear

    @oes_texture_half_float_linear.setter
    def oes_texture_half_float_linear(self, oes_texture_half_float_linear):
        """Sets the oes_texture_half_float_linear of this BTWebClientCapabilitiesParams.


        :param oes_texture_half_float_linear: The oes_texture_half_float_linear of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_texture_half_float_linear = oes_texture_half_float_linear

    @property
    def oes_vertex_array_object(self):
        """Gets the oes_vertex_array_object of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The oes_vertex_array_object of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._oes_vertex_array_object

    @oes_vertex_array_object.setter
    def oes_vertex_array_object(self, oes_vertex_array_object):
        """Sets the oes_vertex_array_object of this BTWebClientCapabilitiesParams.


        :param oes_vertex_array_object: The oes_vertex_array_object of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._oes_vertex_array_object = oes_vertex_array_object

    @property
    def compressed_texture_s3tc(self):
        """Gets the compressed_texture_s3tc of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The compressed_texture_s3tc of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._compressed_texture_s3tc

    @compressed_texture_s3tc.setter
    def compressed_texture_s3tc(self, compressed_texture_s3tc):
        """Sets the compressed_texture_s3tc of this BTWebClientCapabilitiesParams.


        :param compressed_texture_s3tc: The compressed_texture_s3tc of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._compressed_texture_s3tc = compressed_texture_s3tc

    @property
    def draw_buffers(self):
        """Gets the draw_buffers of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The draw_buffers of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._draw_buffers

    @draw_buffers.setter
    def draw_buffers(self, draw_buffers):
        """Sets the draw_buffers of this BTWebClientCapabilitiesParams.


        :param draw_buffers: The draw_buffers of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._draw_buffers = draw_buffers

    @property
    def has3d_mouse(self):
        """Gets the has3d_mouse of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The has3d_mouse of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: bool
        """
        return self._has3d_mouse

    @has3d_mouse.setter
    def has3d_mouse(self, has3d_mouse):
        """Sets the has3d_mouse of this BTWebClientCapabilitiesParams.


        :param has3d_mouse: The has3d_mouse of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: bool
        """

        self._has3d_mouse = has3d_mouse

    @property
    def screen_width(self):
        """Gets the screen_width of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The screen_width of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: int
        """
        return self._screen_width

    @screen_width.setter
    def screen_width(self, screen_width):
        """Sets the screen_width of this BTWebClientCapabilitiesParams.


        :param screen_width: The screen_width of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: int
        """

        self._screen_width = screen_width

    @property
    def screen_height(self):
        """Gets the screen_height of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The screen_height of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: int
        """
        return self._screen_height

    @screen_height.setter
    def screen_height(self, screen_height):
        """Sets the screen_height of this BTWebClientCapabilitiesParams.


        :param screen_height: The screen_height of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: int
        """

        self._screen_height = screen_height

    @property
    def device_pixel_ratio(self):
        """Gets the device_pixel_ratio of this BTWebClientCapabilitiesParams.  # noqa: E501


        :return: The device_pixel_ratio of this BTWebClientCapabilitiesParams.  # noqa: E501
        :rtype: float
        """
        return self._device_pixel_ratio

    @device_pixel_ratio.setter
    def device_pixel_ratio(self, device_pixel_ratio):
        """Sets the device_pixel_ratio of this BTWebClientCapabilitiesParams.


        :param device_pixel_ratio: The device_pixel_ratio of this BTWebClientCapabilitiesParams.  # noqa: E501
        :type: float
        """

        self._device_pixel_ratio = device_pixel_ratio

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTWebClientCapabilitiesParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from onshape_client.models.address import Address
from onshape_client.models.api_response import ApiResponse
from onshape_client.models.api_responses import ApiResponses
from onshape_client.models.btapi_application_deprecate_params import BTAPIApplicationDeprecateParams
from onshape_client.models.btapi_application_params import BTAPIApplicationParams
from onshape_client.models.btapi_application_summary_info import BTAPIApplicationSummaryInfo
from onshape_client.models.btapi_developer_params import BTAPIDeveloperParams
from onshape_client.models.btapi_key_params import BTAPIKeyParams
from onshape_client.models.btapi_partner_params import BTAPIPartnerParams
from onshape_client.models.bt_acl_params import BTAclParams
from onshape_client.models.bt_add_friend_params import BTAddFriendParams
from onshape_client.models.bt_address_info import BTAddressInfo
from onshape_client.models.bt_admin_group_params import BTAdminGroupParams
from onshape_client.models.bt_admin_role_params import BTAdminRoleParams
from onshape_client.models.bt_admin_role_permission_params import BTAdminRolePermissionParams
from onshape_client.models.bt_admin_task_params import BTAdminTaskParams
from onshape_client.models.bt_admin_user_role_params import BTAdminUserRoleParams
from onshape_client.models.bt_agreement_params import BTAgreementParams
from onshape_client.models.bt_api_key_update_params import BTApiKeyUpdateParams
from onshape_client.models.bt_app_associative_data_params_array import BTAppAssociativeDataParamsArray
from onshape_client.models.bt_app_element_change_params import BTAppElementChangeParams
from onshape_client.models.bt_app_element_commit_transaction_params import BTAppElementCommitTransactionParams
from onshape_client.models.bt_app_element_content_delta_info import BTAppElementContentDeltaInfo
from onshape_client.models.bt_app_element_content_entry_info import BTAppElementContentEntryInfo
from onshape_client.models.bt_app_element_content_info import BTAppElementContentInfo
from onshape_client.models.bt_app_element_history_entry_info import BTAppElementHistoryEntryInfo
from onshape_client.models.bt_app_element_history_info import BTAppElementHistoryInfo
from onshape_client.models.bt_app_element_modify_info import BTAppElementModifyInfo
from onshape_client.models.bt_app_element_params import BTAppElementParams
from onshape_client.models.bt_app_element_reference_info import BTAppElementReferenceInfo
from onshape_client.models.bt_app_element_reference_params import BTAppElementReferenceParams
from onshape_client.models.bt_app_element_reference_resolve_info import BTAppElementReferenceResolveInfo
from onshape_client.models.bt_app_element_start_transaction_params import BTAppElementStartTransactionParams
from onshape_client.models.bt_app_element_update_params import BTAppElementUpdateParams
from onshape_client.models.bt_app_view_params import BTAppViewParams
from onshape_client.models.bt_application_element_thumbnail_params import BTApplicationElementThumbnailParams
from onshape_client.models.bt_application_element_thumbnail_params_array import BTApplicationElementThumbnailParamsArray
from onshape_client.models.bt_approve_translation_debug_params import BTApproveTranslationDebugParams
from onshape_client.models.bt_assembly_instance_definition_params import BTAssemblyInstanceDefinitionParams
from onshape_client.models.bt_assembly_transform_definition_params import BTAssemblyTransformDefinitionParams
from onshape_client.models.bt_assembly_transformed_instances_definition_params import BTAssemblyTransformedInstancesDefinitionParams
from onshape_client.models.bt_associative_data_params import BTAssociativeDataParams
from onshape_client.models.bt_associative_field_params import BTAssociativeFieldParams
from onshape_client.models.bt_auto_part_numbering_scheme_params import BTAutoPartNumberingSchemeParams
from onshape_client.models.bt_base_info import BTBaseInfo
from onshape_client.models.bt_bel_script_library_version import BTBelScriptLibraryVersion
from onshape_client.models.bt_beta_capability_admin_info import BTBetaCapabilityAdminInfo
from onshape_client.models.bt_beta_capability_import_info import BTBetaCapabilityImportInfo
from onshape_client.models.bt_beta_capability_info import BTBetaCapabilityInfo
from onshape_client.models.bt_beta_capability_metrics_info import BTBetaCapabilityMetricsInfo
from onshape_client.models.bt_beta_capability_params import BTBetaCapabilityParams
from onshape_client.models.bt_beta_capability_summary_info import BTBetaCapabilitySummaryInfo
from onshape_client.models.bt_beta_capability_user_info import BTBetaCapabilityUserInfo
from onshape_client.models.bt_billing_account_params import BTBillingAccountParams
from onshape_client.models.bt_billing_allowed_plans_info import BTBillingAllowedPlansInfo
from onshape_client.models.bt_billing_plan_batch_params import BTBillingPlanBatchParams
from onshape_client.models.bt_billing_plan_info import BTBillingPlanInfo
from onshape_client.models.bt_billing_plan_params import BTBillingPlanParams
from onshape_client.models.bt_billing_plan_summary_info import BTBillingPlanSummaryInfo
from onshape_client.models.bt_bounding_box import BTBoundingBox
from onshape_client.models.bt_bounding_box_params import BTBoundingBoxParams
from onshape_client.models.bt_broken_out_end_condition import BTBrokenOutEndCondition
from onshape_client.models.bt_bulk_document_update_params import BTBulkDocumentUpdateParams
from onshape_client.models.bt_cache_info import BTCacheInfo
from onshape_client.models.bt_campaign_params import BTCampaignParams
from onshape_client.models.bt_capability_check_params import BTCapabilityCheckParams
from onshape_client.models.bt_capability_params import BTCapabilityParams
from onshape_client.models.bt_capability_rule_params import BTCapabilityRuleParams
from onshape_client.models.bt_capable_info import BTCapableInfo
from onshape_client.models.bt_card_info import BTCardInfo
from onshape_client.models.bt_card_params import BTCardParams
from onshape_client.models.bt_change_context_params import BTChangeContextParams
from onshape_client.models.bt_cloud_storage_account_info import BTCloudStorageAccountInfo
from onshape_client.models.bt_cloud_storage_account_list_info import BTCloudStorageAccountListInfo
from onshape_client.models.bt_cloud_storage_account_params import BTCloudStorageAccountParams
from onshape_client.models.bt_cloud_storage_object_info import BTCloudStorageObjectInfo
from onshape_client.models.bt_cloud_storage_object_list_info import BTCloudStorageObjectListInfo
from onshape_client.models.bt_cloud_storage_provider_object_info import BTCloudStorageProviderObjectInfo
from onshape_client.models.bt_color_info import BTColorInfo
from onshape_client.models.bt_color_params import BTColorParams
from onshape_client.models.bt_comment_attachment_info import BTCommentAttachmentInfo
from onshape_client.models.bt_comment_info import BTCommentInfo
from onshape_client.models.bt_comment_notification_params import BTCommentNotificationParams
from onshape_client.models.bt_comment_params import BTCommentParams
from onshape_client.models.bt_comment_subscription_params import BTCommentSubscriptionParams
from onshape_client.models.bt_company_activate_params import BTCompanyActivateParams
from onshape_client.models.bt_company_no_public_document_params import BTCompanyNoPublicDocumentParams
from onshape_client.models.bt_company_params import BTCompanyParams
from onshape_client.models.bt_company_policies_params import BTCompanyPoliciesParams
from onshape_client.models.bt_company_summary_info import BTCompanySummaryInfo
from onshape_client.models.bt_company_transfer_params import BTCompanyTransferParams
from onshape_client.models.bt_company_user_params import BTCompanyUserParams
from onshape_client.models.bt_component_usages_summary import BTComponentUsagesSummary
from onshape_client.models.bt_configuration_id_info import BTConfigurationIdInfo
from onshape_client.models.bt_configuration_info import BTConfigurationInfo
from onshape_client.models.bt_configuration_params import BTConfigurationParams
from onshape_client.models.bt_connection import BTConnection
from onshape_client.models.bt_copy_document_params import BTCopyDocumentParams
from onshape_client.models.bt_copy_element_params import BTCopyElementParams
from onshape_client.models.bt_curve_description import BTCurveDescription
from onshape_client.models.bt_custom_property_definition_info import BTCustomPropertyDefinitionInfo
from onshape_client.models.bt_custom_property_definition_params import BTCustomPropertyDefinitionParams
from onshape_client.models.btdb_viewer_collection_config import BTDBViewerCollectionConfig
from onshape_client.models.btdb_viewer_config import BTDBViewerConfig
from onshape_client.models.btdb_viewer_query_params import BTDBViewerQueryParams
from onshape_client.models.bt_device_info import BTDeviceInfo
from onshape_client.models.bt_device_token_params import BTDeviceTokenParams
from onshape_client.models.bt_diff_info import BTDiffInfo
from onshape_client.models.bt_discount_info import BTDiscountInfo
from onshape_client.models.bt_discount_params import BTDiscountParams
from onshape_client.models.bt_document_check_access_params import BTDocumentCheckAccessParams
from onshape_client.models.bt_document_element_info import BTDocumentElementInfo
from onshape_client.models.bt_document_info import BTDocumentInfo
from onshape_client.models.bt_document_label_info import BTDocumentLabelInfo
from onshape_client.models.bt_document_label_params import BTDocumentLabelParams
from onshape_client.models.bt_document_merge_info import BTDocumentMergeInfo
from onshape_client.models.bt_document_microversion_info import BTDocumentMicroversionInfo
from onshape_client.models.bt_document_migrate_params import BTDocumentMigrateParams
from onshape_client.models.bt_document_options_params import BTDocumentOptionsParams
from onshape_client.models.bt_document_params import BTDocumentParams
from onshape_client.models.bt_document_processing_info import BTDocumentProcessingInfo
from onshape_client.models.bt_document_scope import BTDocumentScope
from onshape_client.models.bt_document_search_hit_info import BTDocumentSearchHitInfo
from onshape_client.models.bt_document_search_params import BTDocumentSearchParams
from onshape_client.models.bt_document_summary_info import BTDocumentSummaryInfo
from onshape_client.models.bt_document_summary_search_info import BTDocumentSummarySearchInfo
from onshape_client.models.bt_document_version_element_ids import BTDocumentVersionElementIds
from onshape_client.models.bt_document_with_version_and_element_id import BTDocumentWithVersionAndElementId
from onshape_client.models.bt_document_with_version_id import BTDocumentWithVersionId
from onshape_client.models.bt_drawing_params import BTDrawingParams
from onshape_client.models.btes_document_hit import BTESDocumentHit
from onshape_client.models.bt_element_location_params import BTElementLocationParams
from onshape_client.models.bt_element_params import BTElementParams
from onshape_client.models.bt_element_properties_params import BTElementPropertiesParams
from onshape_client.models.bt_element_rename_params import BTElementRenameParams
from onshape_client.models.bt_element_thumbnail_data_params import BTElementThumbnailDataParams
from onshape_client.models.bt_enterprise_report_params import BTEnterpriseReportParams
from onshape_client.models.bt_export_model_bodies_response import BTExportModelBodiesResponse
from onshape_client.models.bt_export_model_body import BTExportModelBody
from onshape_client.models.bt_export_model_coedge import BTExportModelCoedge
from onshape_client.models.bt_export_model_edge import BTExportModelEdge
from onshape_client.models.bt_export_model_edge_geometry import BTExportModelEdgeGeometry
from onshape_client.models.bt_export_model_face import BTExportModelFace
from onshape_client.models.bt_export_model_loop import BTExportModelLoop
from onshape_client.models.bt_export_model_params import BTExportModelParams
from onshape_client.models.bt_export_model_vertex import BTExportModelVertex
from onshape_client.models.bt_export_tessellated_edges_body import BTExportTessellatedEdgesBody
from onshape_client.models.bt_export_tessellated_edges_edge import BTExportTessellatedEdgesEdge
from onshape_client.models.bt_export_tessellated_edges_response import BTExportTessellatedEdgesResponse
from onshape_client.models.bt_export_tessellated_faces_body import BTExportTessellatedFacesBody
from onshape_client.models.bt_export_tessellated_faces_face import BTExportTessellatedFacesFace
from onshape_client.models.bt_export_tessellated_faces_facet import BTExportTessellatedFacesFacet
from onshape_client.models.bt_export_tessellated_faces_response import BTExportTessellatedFacesResponse
from onshape_client.models.bt_extend_trial_params import BTExtendTrialParams
from onshape_client.models.bt_external_element_reference_info import BTExternalElementReferenceInfo
from onshape_client.models.btfs_value import BTFSValue
from onshape_client.models.bt_feature_definition_response import BTFeatureDefinitionResponse
from onshape_client.models.bt_feature_list_response import BTFeatureListResponse
from onshape_client.models.bt_feature_script_eval_call import BTFeatureScriptEvalCall
from onshape_client.models.bt_feature_script_eval_response import BTFeatureScriptEvalResponse
from onshape_client.models.bt_feature_state import BTFeatureState
from onshape_client.models.bt_folder_info import BTFolderInfo
from onshape_client.models.bt_folder_params import BTFolderParams
from onshape_client.models.bt_friend_info import BTFriendInfo
from onshape_client.models.bt_friends_from_ids_params import BTFriendsFromIdsParams
from onshape_client.models.bt_global_permission_definitions_info import BTGlobalPermissionDefinitionsInfo
from onshape_client.models.bt_global_permission_info import BTGlobalPermissionInfo
from onshape_client.models.bt_global_permission_params import BTGlobalPermissionParams
from onshape_client.models.bt_global_tree_magic_node_info import BTGlobalTreeMagicNodeInfo
from onshape_client.models.bt_global_tree_node_info import BTGlobalTreeNodeInfo
from onshape_client.models.bt_global_tree_node_info_list_bt_global_tree_node_info import BTGlobalTreeNodeInfoListBTGlobalTreeNodeInfo
from onshape_client.models.bt_global_tree_node_list_response import BTGlobalTreeNodeListResponse
from onshape_client.models.bt_global_tree_node_move_params import BTGlobalTreeNodeMoveParams
from onshape_client.models.bt_global_tree_node_owner_params import BTGlobalTreeNodeOwnerParams
from onshape_client.models.bt_global_tree_node_with_children_info import BTGlobalTreeNodeWithChildrenInfo
from onshape_client.models.bt_graphics_appearance import BTGraphicsAppearance
from onshape_client.models.bt_id_and_configuration import BTIdAndConfiguration
from onshape_client.models.bt_id_translation_info import BTIdTranslationInfo
from onshape_client.models.bt_id_translation_params import BTIdTranslationParams
from onshape_client.models.bt_id_translation_result_info import BTIdTranslationResultInfo
from onshape_client.models.bt_identity import BTIdentity
from onshape_client.models.bt_identity_info import BTIdentityInfo
from onshape_client.models.bt_identity_management_params import BTIdentityManagementParams
from onshape_client.models.bt_identity_params import BTIdentityParams
from onshape_client.models.bt_import_cloud_object_params import BTImportCloudObjectParams
from onshape_client.models.bt_import_foreign_data_params import BTImportForeignDataParams
from onshape_client.models.bt_in_app_message_content import BTInAppMessageContent
from onshape_client.models.bt_in_app_message_content_item import BTInAppMessageContentItem
from onshape_client.models.bt_in_app_message_info import BTInAppMessageInfo
from onshape_client.models.bt_in_app_message_params import BTInAppMessageParams
from onshape_client.models.bt_insertion_location import BTInsertionLocation
from onshape_client.models.bt_invitation_params import BTInvitationParams
from onshape_client.models.bt_item_params import BTItemParams
from onshape_client.models.bt_link_to_latest_document_params import BTLinkToLatestDocumentParams
from onshape_client.models.bt_list_response_bt_beta_capability_summary_info import BTListResponseBTBetaCapabilitySummaryInfo
from onshape_client.models.bt_list_response_bt_beta_capability_user_info import BTListResponseBTBetaCapabilityUserInfo
from onshape_client.models.bt_list_response_bt_cloud_storage_provider_object_info import BTListResponseBTCloudStorageProviderObjectInfo
from onshape_client.models.bt_list_response_bt_friend_info import BTListResponseBTFriendInfo
from onshape_client.models.bt_list_response_bt_in_app_message_info import BTListResponseBTInAppMessageInfo
from onshape_client.models.bt_list_response_bt_purchase_info import BTListResponseBTPurchaseInfo
from onshape_client.models.bt_list_response_bt_standard_content_hierarchy_info import BTListResponseBTStandardContentHierarchyInfo
from onshape_client.models.bt_list_response_bt_system_config_info import BTListResponseBTSystemConfigInfo
from onshape_client.models.bt_location_info import BTLocationInfo
from onshape_client.models.bt_login_params import BTLoginParams
from onshape_client.models.bt_login_totp_params import BTLoginTotpParams
from onshape_client.models.btm_feature import BTMFeature
from onshape_client.models.btm_import import BTMImport
from onshape_client.models.btm_parameter import BTMParameter
from onshape_client.models.btm_suppression_state import BTMSuppressionState
from onshape_client.models.bt_mass_prop_response import BTMassPropResponse
from onshape_client.models.bt_mass_properties import BTMassProperties
from onshape_client.models.bt_matching_standard_content_hierarchy_info import BTMatchingStandardContentHierarchyInfo
from onshape_client.models.bt_material_params import BTMaterialParams
from onshape_client.models.bt_material_property_params import BTMaterialPropertyParams
from onshape_client.models.bt_metadata_enum_value_info import BTMetadataEnumValueInfo
from onshape_client.models.bt_metadata_property_config_params import BTMetadataPropertyConfigParams
from onshape_client.models.bt_metadata_property_info import BTMetadataPropertyInfo
from onshape_client.models.bt_metadata_property_params import BTMetadataPropertyParams
from onshape_client.models.bt_metadata_property_ui_hints_info import BTMetadataPropertyUiHintsInfo
from onshape_client.models.bt_metadata_property_validator_info import BTMetadataPropertyValidatorInfo
from onshape_client.models.bt_metadata_schema_params import BTMetadataSchemaParams
from onshape_client.models.bt_metric_params import BTMetricParams
from onshape_client.models.bt_metrics_list_params import BTMetricsListParams
from onshape_client.models.bt_microversion_id import BTMicroversionId
from onshape_client.models.bt_mobile_notification_params import BTMobileNotificationParams
from onshape_client.models.bt_model_body_params import BTModelBodyParams
from onshape_client.models.bt_model_element_params import BTModelElementParams
from onshape_client.models.bt_model_format_info import BTModelFormatInfo
from onshape_client.models.bt_model_tessellation_params import BTModelTessellationParams
from onshape_client.models.bt_move_element_info import BTMoveElementInfo
from onshape_client.models.bt_move_element_params import BTMoveElementParams
from onshape_client.models.bt_name_value_pair import BTNameValuePair
from onshape_client.models.bt_named_view_info import BTNamedViewInfo
from onshape_client.models.bt_named_views_info import BTNamedViewsInfo
from onshape_client.models.bt_next_part_number_param import BTNextPartNumberParam
from onshape_client.models.bt_next_part_numbers_param import BTNextPartNumbersParam
from onshape_client.models.bt_next_revision_params import BTNextRevisionParams
from onshape_client.models.bt_node_reference import BTNodeReference
from onshape_client.models.bt_node_status import BTNodeStatus
from onshape_client.models.bt_notice import BTNotice
from onshape_client.models.bt_notification_debug_params import BTNotificationDebugParams
from onshape_client.models.bt_notification_params import BTNotificationParams
from onshape_client.models.bt_object_id import BTObjectId
from onshape_client.models.bt_occurrence import BTOccurrence
from onshape_client.models.bt_owner_info import BTOwnerInfo
from onshape_client.models.btpdm_metadata_params import BTPDMMetadataParams
from onshape_client.models.btp_literal_string import BTPLiteralString
from onshape_client.models.btp_module_id import BTPModuleId
from onshape_client.models.btp_node import BTPNode
from onshape_client.models.btp_space import BTPSpace
from onshape_client.models.bt_part_appearance_info import BTPartAppearanceInfo
from onshape_client.models.bt_part_appearance_params import BTPartAppearanceParams
from onshape_client.models.bt_part_id_params import BTPartIdParams
from onshape_client.models.bt_part_material_info import BTPartMaterialInfo
from onshape_client.models.bt_part_material_property_info import BTPartMaterialPropertyInfo
from onshape_client.models.bt_part_metadata_info import BTPartMetadataInfo
from onshape_client.models.bt_part_query_params import BTPartQueryParams
from onshape_client.models.bt_password_reset_params import BTPasswordResetParams
from onshape_client.models.bt_payment_type_params import BTPaymentTypeParams
from onshape_client.models.bt_permission_set import BTPermissionSet
from onshape_client.models.bt_plan_subscriber_info import BTPlanSubscriberInfo
from onshape_client.models.bt_project_info import BTProjectInfo
from onshape_client.models.bt_project_params import BTProjectParams
from onshape_client.models.bt_property_value_param import BTPropertyValueParam
from onshape_client.models.bt_publish_workflow_params import BTPublishWorkflowParams
from onshape_client.models.bt_purchase_info import BTPurchaseInfo
from onshape_client.models.bt_purchase_params import BTPurchaseParams
from onshape_client.models.bt_purchase_user_info import BTPurchaseUserInfo
from onshape_client.models.bt_purchase_user_params import BTPurchaseUserParams
from onshape_client.models.bt_query_revision_params import BTQueryRevisionParams
from onshape_client.models.bt_rbac_permission_scheme_entry_params import BTRbacPermissionSchemeEntryParams
from onshape_client.models.bt_rbac_permission_scheme_info import BTRbacPermissionSchemeInfo
from onshape_client.models.bt_rbac_permission_scheme_list_info import BTRbacPermissionSchemeListInfo
from onshape_client.models.bt_rbac_permission_scheme_params import BTRbacPermissionSchemeParams
from onshape_client.models.bt_rbac_role_info import BTRbacRoleInfo
from onshape_client.models.bt_rbac_role_params import BTRbacRoleParams
from onshape_client.models.bt_release_package_info import BTReleasePackageInfo
from onshape_client.models.bt_release_package_item import BTReleasePackageItem
from onshape_client.models.bt_release_package_item_error import BTReleasePackageItemError
from onshape_client.models.bt_release_package_item_info import BTReleasePackageItemInfo
from onshape_client.models.bt_release_package_item_params import BTReleasePackageItemParams
from onshape_client.models.bt_release_package_params import BTReleasePackageParams
from onshape_client.models.bt_release_package_workflow_change_params import BTReleasePackageWorkflowChangeParams
from onshape_client.models.bt_repair_context_params import BTRepairContextParams
from onshape_client.models.bt_revision_custom_data import BTRevisionCustomData
from onshape_client.models.bt_revision_params import BTRevisionParams
from onshape_client.models.bt_revision_rule_info import BTRevisionRuleInfo
from onshape_client.models.bt_revision_rule_params import BTRevisionRuleParams
from onshape_client.models.bt_root_diff_info import BTRootDiffInfo
from onshape_client.models.bt_seats_params import BTSeatsParams
from onshape_client.models.bt_section_plane_info import BTSectionPlaneInfo
from onshape_client.models.bt_send_grid_delivery_event_params import BTSendGridDeliveryEventParams
from onshape_client.models.bt_setting_info import BTSettingInfo
from onshape_client.models.bt_setting_param import BTSettingParam
from onshape_client.models.bt_shaded_render_document_response import BTShadedRenderDocumentResponse
from onshape_client.models.bt_share_entry_params import BTShareEntryParams
from onshape_client.models.bt_share_params import BTShareParams
from onshape_client.models.bt_simple_info import BTSimpleInfo
from onshape_client.models.bt_standard_content_custom_parameter_definition import BTStandardContentCustomParameterDefinition
from onshape_client.models.bt_standard_content_custom_parameter_definition_id import BTStandardContentCustomParameterDefinitionId
from onshape_client.models.bt_standard_content_custom_parameter_params import BTStandardContentCustomParameterParams
from onshape_client.models.bt_standard_content_find_usage_params import BTStandardContentFindUsageParams
from onshape_client.models.bt_standard_content_hierarchy import BTStandardContentHierarchy
from onshape_client.models.bt_standard_content_hierarchy_info import BTStandardContentHierarchyInfo
from onshape_client.models.bt_standard_content_hierarchy_params import BTStandardContentHierarchyParams
from onshape_client.models.bt_standard_content_hierarchy_rename_params import BTStandardContentHierarchyRenameParams
from onshape_client.models.bt_standard_content_parameter_definition import BTStandardContentParameterDefinition
from onshape_client.models.bt_standard_content_params import BTStandardContentParams
from onshape_client.models.bt_standard_content_set_run_versions_params import BTStandardContentSetRunVersionsParams
from onshape_client.models.bt_standard_content_usage_summary import BTStandardContentUsageSummary
from onshape_client.models.bt_start_edit_in_context_params import BTStartEditInContextParams
from onshape_client.models.bt_substitute_approver_params import BTSubstituteApproverParams
from onshape_client.models.bt_surface_description import BTSurfaceDescription
from onshape_client.models.bt_survey_response_params import BTSurveyResponseParams
from onshape_client.models.bt_system_config_info import BTSystemConfigInfo
from onshape_client.models.bt_tag_params import BTTagParams
from onshape_client.models.bt_team_info import BTTeamInfo
from onshape_client.models.bt_team_member_params import BTTeamMemberParams
from onshape_client.models.bt_team_params import BTTeamParams
from onshape_client.models.bt_team_summary_info import BTTeamSummaryInfo
from onshape_client.models.bt_thumbnail_info import BTThumbnailInfo
from onshape_client.models.bt_thumbnail_size_info import BTThumbnailSizeInfo
from onshape_client.models.bt_tool_tree_params import BTToolTreeParams
from onshape_client.models.bt_tool_tree_update_params import BTToolTreeUpdateParams
from onshape_client.models.bt_trace_params import BTTraceParams
from onshape_client.models.bt_translate_format_params import BTTranslateFormatParams
from onshape_client.models.bt_translate_internal_params import BTTranslateInternalParams
from onshape_client.models.bt_translation_request_info import BTTranslationRequestInfo
from onshape_client.models.bt_unique_document_item_params import BTUniqueDocumentItemParams
from onshape_client.models.bt_update_document_thumbnail_params import BTUpdateDocumentThumbnailParams
from onshape_client.models.bt_update_element_thumbnail_params import BTUpdateElementThumbnailParams
from onshape_client.models.bt_update_external_reference_params import BTUpdateExternalReferenceParams
from onshape_client.models.bt_update_in_context_params import BTUpdateInContextParams
from onshape_client.models.bt_update_rbac_role_params import BTUpdateRbacRoleParams
from onshape_client.models.bt_update_reference_params import BTUpdateReferenceParams
from onshape_client.models.bt_update_release_package_params import BTUpdateReleasePackageParams
from onshape_client.models.bt_update_version_thumbnail_params import BTUpdateVersionThumbnailParams
from onshape_client.models.bt_update_workflowable_test_object_params import BTUpdateWorkflowableTestObjectParams
from onshape_client.models.bt_upgrade_on_demand_params import BTUpgradeOnDemandParams
from onshape_client.models.bt_upload_params import BTUploadParams
from onshape_client.models.bt_upload_state_params import BTUploadStateParams
from onshape_client.models.bt_user_activation_params import BTUserActivationParams
from onshape_client.models.bt_user_agent_version import BTUserAgentVersion
from onshape_client.models.bt_user_app_settings_info import BTUserAppSettingsInfo
from onshape_client.models.bt_user_app_settings_params import BTUserAppSettingsParams
from onshape_client.models.bt_user_basic_summary_info import BTUserBasicSummaryInfo
from onshape_client.models.bt_user_email_params import BTUserEmailParams
from onshape_client.models.bt_user_email_verify_params import BTUserEmailVerifyParams
from onshape_client.models.bt_user_notification_pref_levels_info import BTUserNotificationPrefLevelsInfo
from onshape_client.models.bt_user_notification_pref_params import BTUserNotificationPrefParams
from onshape_client.models.bt_user_params import BTUserParams
from onshape_client.models.bt_user_settings_params import BTUserSettingsParams
from onshape_client.models.bt_user_summary_info import BTUserSummaryInfo
from onshape_client.models.bt_user_totp_params import BTUserTotpParams
from onshape_client.models.bt_user_update_params import BTUserUpdateParams
from onshape_client.models.bt_user_update_specs_params import BTUserUpdateSpecsParams
from onshape_client.models.bt_user_usages_summary import BTUserUsagesSummary
from onshape_client.models.bt_user_web_preferences_params import BTUserWebPreferencesParams
from onshape_client.models.bt_validate_workflow_params import BTValidateWorkflowParams
from onshape_client.models.bt_vector2d import BTVector2d
from onshape_client.models.bt_vector3d import BTVector3d
from onshape_client.models.bt_version_info import BTVersionInfo
from onshape_client.models.bt_version_or_workspace_info import BTVersionOrWorkspaceInfo
from onshape_client.models.bt_version_or_workspace_params import BTVersionOrWorkspaceParams
from onshape_client.models.bt_view_data_info import BTViewDataInfo
from onshape_client.models.bt_view_data_params import BTViewDataParams
from onshape_client.models.bt_web_client_capabilities_params import BTWebClientCapabilitiesParams
from onshape_client.models.bt_web_renderer_performance_measurement_params import BTWebRendererPerformanceMeasurementParams
from onshape_client.models.bt_webhook_options import BTWebhookOptions
from onshape_client.models.bt_webhook_params import BTWebhookParams
from onshape_client.models.bt_workflow_action_info import BTWorkflowActionInfo
from onshape_client.models.bt_workflow_property_info import BTWorkflowPropertyInfo
from onshape_client.models.bt_workflow_snapshot_info import BTWorkflowSnapshotInfo
from onshape_client.models.bt_workflow_state_info import BTWorkflowStateInfo
from onshape_client.models.bt_workflowable_test_object_info import BTWorkflowableTestObjectInfo
from onshape_client.models.bt_workspace_info import BTWorkspaceInfo
from onshape_client.models.bt_workspace_part_params import BTWorkspacePartParams
from onshape_client.models.body_part import BodyPart
from onshape_client.models.body_part_headers import BodyPartHeaders
from onshape_client.models.body_part_media_type import BodyPartMediaType
from onshape_client.models.callback import Callback
from onshape_client.models.card import Card
from onshape_client.models.client_log_entry import ClientLogEntry
from onshape_client.models.cloud_object_path_segment import CloudObjectPathSegment
from onshape_client.models.components import Components
from onshape_client.models.configuration_entry import ConfigurationEntry
from onshape_client.models.configuration_info_entry import ConfigurationInfoEntry
from onshape_client.models.contact import Contact
from onshape_client.models.content import Content
from onshape_client.models.content_disposition import ContentDisposition
from onshape_client.models.content_item import ContentItem
from onshape_client.models.coupon import Coupon
from onshape_client.models.customer import Customer
from onshape_client.models.customer_card_collection import CustomerCardCollection
from onshape_client.models.customer_subscription_collection import CustomerSubscriptionCollection
from onshape_client.models.definition import Definition
from onshape_client.models.discount import Discount
from onshape_client.models.discriminator import Discriminator
from onshape_client.models.encoding import Encoding
from onshape_client.models.entry import Entry
from onshape_client.models.example import Example
from onshape_client.models.external_account import ExternalAccount
from onshape_client.models.external_account_collection import ExternalAccountCollection
from onshape_client.models.external_documentation import ExternalDocumentation
from onshape_client.models.form_data_body_part import FormDataBodyPart
from onshape_client.models.form_data_content_disposition import FormDataContentDisposition
from onshape_client.models.form_data_multi_part import FormDataMultiPart
from onshape_client.models.global_permission_info import GlobalPermissionInfo
from onshape_client.models.header import Header
from onshape_client.models.info import Info
from onshape_client.models.item import Item
from onshape_client.models.json_node import JsonNode
from onshape_client.models.level_info import LevelInfo
from onshape_client.models.license import License
from onshape_client.models.link import Link
from onshape_client.models.media_type import MediaType
from onshape_client.models.message import Message
from onshape_client.models.message_body_workers import MessageBodyWorkers
from onshape_client.models.multi_part import MultiPart
from onshape_client.models.next_charge import NextCharge
from onshape_client.models.next_recurring_charge import NextRecurringCharge
from onshape_client.models.o_auth_flow import OAuthFlow
from onshape_client.models.o_auth_flow_scopes import OAuthFlowScopes
from onshape_client.models.o_auth_flows import OAuthFlows
from onshape_client.models.open_api import OpenAPI
from onshape_client.models.operation import Operation
from onshape_client.models.operation_responses import OperationResponses
from onshape_client.models.parameter import Parameter
from onshape_client.models.parameterized_header import ParameterizedHeader
from onshape_client.models.path_item import PathItem
from onshape_client.models.path_segment import PathSegment
from onshape_client.models.paths import Paths
from onshape_client.models.plan import Plan
from onshape_client.models.prorated_charges import ProratedCharges
from onshape_client.models.request_body import RequestBody
from onshape_client.models.request_options import RequestOptions
from onshape_client.models.role_map_entry import RoleMapEntry
from onshape_client.models.schema import Schema
from onshape_client.models.scopes import Scopes
from onshape_client.models.security_requirement import SecurityRequirement
from onshape_client.models.security_scheme import SecurityScheme
from onshape_client.models.server import Server
from onshape_client.models.server_variable import ServerVariable
from onshape_client.models.server_variables import ServerVariables
from onshape_client.models.shipping_details import ShippingDetails
from onshape_client.models.subscription import Subscription
from onshape_client.models.subscription_item import SubscriptionItem
from onshape_client.models.subscription_item_collection import SubscriptionItemCollection
from onshape_client.models.tag import Tag
from onshape_client.models.three_d_secure import ThreeDSecure
from onshape_client.models.transform_group import TransformGroup
from onshape_client.models.update_params import UpdateParams
from onshape_client.models.version_specs import VersionSpecs
from onshape_client.models.xml import XML



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTCompanySummaryInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'state': 'int',
        'type': 'int',
        'description': 'str',
        'owner_id': 'str',
        'domain_prefix': 'str',
        'admin': 'bool',
        'no_public_documents': 'bool',
        'enterprise_base_url': 'str',
        'image': 'str',
        'name': 'str',
        'id': 'str',
        'href': 'str',
        'view_ref': 'str'
    }

    attribute_map = {
        'state': 'state',
        'type': 'type',
        'description': 'description',
        'owner_id': 'ownerId',
        'domain_prefix': 'domainPrefix',
        'admin': 'admin',
        'no_public_documents': 'noPublicDocuments',
        'enterprise_base_url': 'enterpriseBaseUrl',
        'image': 'image',
        'name': 'name',
        'id': 'id',
        'href': 'href',
        'view_ref': 'viewRef'
    }

    def __init__(self, state=None, type=None, description=None, owner_id=None, domain_prefix=None, admin=None, no_public_documents=None, enterprise_base_url=None, image=None, name=None, id=None, href=None, view_ref=None):  # noqa: E501
        """BTCompanySummaryInfo - a model defined in OpenAPI"""  # noqa: E501

        self._state = None
        self._type = None
        self._description = None
        self._owner_id = None
        self._domain_prefix = None
        self._admin = None
        self._no_public_documents = None
        self._enterprise_base_url = None
        self._image = None
        self._name = None
        self._id = None
        self._href = None
        self._view_ref = None
        self.discriminator = None

        if state is not None:
            self.state = state
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if owner_id is not None:
            self.owner_id = owner_id
        if domain_prefix is not None:
            self.domain_prefix = domain_prefix
        if admin is not None:
            self.admin = admin
        if no_public_documents is not None:
            self.no_public_documents = no_public_documents
        if enterprise_base_url is not None:
            self.enterprise_base_url = enterprise_base_url
        if image is not None:
            self.image = image
        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if href is not None:
            self.href = href
        if view_ref is not None:
            self.view_ref = view_ref

    @property
    def state(self):
        """Gets the state of this BTCompanySummaryInfo.  # noqa: E501


        :return: The state of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this BTCompanySummaryInfo.


        :param state: The state of this BTCompanySummaryInfo.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def type(self):
        """Gets the type of this BTCompanySummaryInfo.  # noqa: E501


        :return: The type of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTCompanySummaryInfo.


        :param type: The type of this BTCompanySummaryInfo.  # noqa: E501
        :type: int
        """

        self._type = type

    @property
    def description(self):
        """Gets the description of this BTCompanySummaryInfo.  # noqa: E501


        :return: The description of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTCompanySummaryInfo.


        :param description: The description of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def owner_id(self):
        """Gets the owner_id of this BTCompanySummaryInfo.  # noqa: E501


        :return: The owner_id of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this BTCompanySummaryInfo.


        :param owner_id: The owner_id of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._owner_id = owner_id

    @property
    def domain_prefix(self):
        """Gets the domain_prefix of this BTCompanySummaryInfo.  # noqa: E501


        :return: The domain_prefix of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._domain_prefix

    @domain_prefix.setter
    def domain_prefix(self, domain_prefix):
        """Sets the domain_prefix of this BTCompanySummaryInfo.


        :param domain_prefix: The domain_prefix of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._domain_prefix = domain_prefix

    @property
    def admin(self):
        """Gets the admin of this BTCompanySummaryInfo.  # noqa: E501


        :return: The admin of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this BTCompanySummaryInfo.


        :param admin: The admin of this BTCompanySummaryInfo.  # noqa: E501
        :type: bool
        """

        self._admin = admin

    @property
    def no_public_documents(self):
        """Gets the no_public_documents of this BTCompanySummaryInfo.  # noqa: E501


        :return: The no_public_documents of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: bool
        """
        return self._no_public_documents

    @no_public_documents.setter
    def no_public_documents(self, no_public_documents):
        """Sets the no_public_documents of this BTCompanySummaryInfo.


        :param no_public_documents: The no_public_documents of this BTCompanySummaryInfo.  # noqa: E501
        :type: bool
        """

        self._no_public_documents = no_public_documents

    @property
    def enterprise_base_url(self):
        """Gets the enterprise_base_url of this BTCompanySummaryInfo.  # noqa: E501


        :return: The enterprise_base_url of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._enterprise_base_url

    @enterprise_base_url.setter
    def enterprise_base_url(self, enterprise_base_url):
        """Sets the enterprise_base_url of this BTCompanySummaryInfo.


        :param enterprise_base_url: The enterprise_base_url of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._enterprise_base_url = enterprise_base_url

    @property
    def image(self):
        """Gets the image of this BTCompanySummaryInfo.  # noqa: E501


        :return: The image of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BTCompanySummaryInfo.


        :param image: The image of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def name(self):
        """Gets the name of this BTCompanySummaryInfo.  # noqa: E501


        :return: The name of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTCompanySummaryInfo.


        :param name: The name of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTCompanySummaryInfo.  # noqa: E501


        :return: The id of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTCompanySummaryInfo.


        :param id: The id of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def href(self):
        """Gets the href of this BTCompanySummaryInfo.  # noqa: E501


        :return: The href of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this BTCompanySummaryInfo.


        :param href: The href of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def view_ref(self):
        """Gets the view_ref of this BTCompanySummaryInfo.  # noqa: E501


        :return: The view_ref of this BTCompanySummaryInfo.  # noqa: E501
        :rtype: str
        """
        return self._view_ref

    @view_ref.setter
    def view_ref(self, view_ref):
        """Sets the view_ref of this BTCompanySummaryInfo.


        :param view_ref: The view_ref of this BTCompanySummaryInfo.  # noqa: E501
        :type: str
        """

        self._view_ref = view_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTCompanySummaryInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTDocumentElementInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'type': 'str',
        'element_type': 'str',
        'data_type': 'str',
        'thumbnails': 'str',
        'microversion_id': 'str',
        'filename': 'str',
        'thumbnail_info': 'BTThumbnailInfo',
        'foreign_data_id': 'str',
        'length_units': 'str',
        'angle_units': 'str',
        'mass_units': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'type': 'type',
        'element_type': 'elementType',
        'data_type': 'dataType',
        'thumbnails': 'thumbnails',
        'microversion_id': 'microversionId',
        'filename': 'filename',
        'thumbnail_info': 'thumbnailInfo',
        'foreign_data_id': 'foreignDataId',
        'length_units': 'lengthUnits',
        'angle_units': 'angleUnits',
        'mass_units': 'massUnits'
    }

    def __init__(self, name=None, id=None, type=None, element_type=None, data_type=None, thumbnails=None, microversion_id=None, filename=None, thumbnail_info=None, foreign_data_id=None, length_units=None, angle_units=None, mass_units=None):  # noqa: E501
        """BTDocumentElementInfo - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._id = None
        self._type = None
        self._element_type = None
        self._data_type = None
        self._thumbnails = None
        self._microversion_id = None
        self._filename = None
        self._thumbnail_info = None
        self._foreign_data_id = None
        self._length_units = None
        self._angle_units = None
        self._mass_units = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if element_type is not None:
            self.element_type = element_type
        if data_type is not None:
            self.data_type = data_type
        if thumbnails is not None:
            self.thumbnails = thumbnails
        if microversion_id is not None:
            self.microversion_id = microversion_id
        if filename is not None:
            self.filename = filename
        if thumbnail_info is not None:
            self.thumbnail_info = thumbnail_info
        if foreign_data_id is not None:
            self.foreign_data_id = foreign_data_id
        if length_units is not None:
            self.length_units = length_units
        if angle_units is not None:
            self.angle_units = angle_units
        if mass_units is not None:
            self.mass_units = mass_units

    @property
    def name(self):
        """Gets the name of this BTDocumentElementInfo.  # noqa: E501


        :return: The name of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTDocumentElementInfo.


        :param name: The name of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this BTDocumentElementInfo.  # noqa: E501


        :return: The id of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BTDocumentElementInfo.


        :param id: The id of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this BTDocumentElementInfo.  # noqa: E501


        :return: The type of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BTDocumentElementInfo.


        :param type: The type of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def element_type(self):
        """Gets the element_type of this BTDocumentElementInfo.  # noqa: E501


        :return: The element_type of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._element_type

    @element_type.setter
    def element_type(self, element_type):
        """Sets the element_type of this BTDocumentElementInfo.


        :param element_type: The element_type of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["PARTSTUDIO", "ASSEMBLY", "DRAWING", "FEATURESTUDIO", "BLOB", "APPLICATION", "TABLE", "BILLOFMATERIALS", "UNKNOWN"]  # noqa: E501
        if element_type not in allowed_values:
            raise ValueError(
                "Invalid value for `element_type` ({0}), must be one of {1}"  # noqa: E501
                .format(element_type, allowed_values)
            )

        self._element_type = element_type

    @property
    def data_type(self):
        """Gets the data_type of this BTDocumentElementInfo.  # noqa: E501


        :return: The data_type of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this BTDocumentElementInfo.


        :param data_type: The data_type of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def thumbnails(self):
        """Gets the thumbnails of this BTDocumentElementInfo.  # noqa: E501


        :return: The thumbnails of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._thumbnails

    @thumbnails.setter
    def thumbnails(self, thumbnails):
        """Sets the thumbnails of this BTDocumentElementInfo.


        :param thumbnails: The thumbnails of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._thumbnails = thumbnails

    @property
    def microversion_id(self):
        """Gets the microversion_id of this BTDocumentElementInfo.  # noqa: E501


        :return: The microversion_id of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._microversion_id

    @microversion_id.setter
    def microversion_id(self, microversion_id):
        """Sets the microversion_id of this BTDocumentElementInfo.


        :param microversion_id: The microversion_id of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._microversion_id = microversion_id

    @property
    def filename(self):
        """Gets the filename of this BTDocumentElementInfo.  # noqa: E501


        :return: The filename of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this BTDocumentElementInfo.


        :param filename: The filename of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._filename = filename

    @property
    def thumbnail_info(self):
        """Gets the thumbnail_info of this BTDocumentElementInfo.  # noqa: E501


        :return: The thumbnail_info of this BTDocumentElementInfo.  # noqa: E501
        :rtype: BTThumbnailInfo
        """
        return self._thumbnail_info

    @thumbnail_info.setter
    def thumbnail_info(self, thumbnail_info):
        """Sets the thumbnail_info of this BTDocumentElementInfo.


        :param thumbnail_info: The thumbnail_info of this BTDocumentElementInfo.  # noqa: E501
        :type: BTThumbnailInfo
        """

        self._thumbnail_info = thumbnail_info

    @property
    def foreign_data_id(self):
        """Gets the foreign_data_id of this BTDocumentElementInfo.  # noqa: E501


        :return: The foreign_data_id of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._foreign_data_id

    @foreign_data_id.setter
    def foreign_data_id(self, foreign_data_id):
        """Sets the foreign_data_id of this BTDocumentElementInfo.


        :param foreign_data_id: The foreign_data_id of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._foreign_data_id = foreign_data_id

    @property
    def length_units(self):
        """Gets the length_units of this BTDocumentElementInfo.  # noqa: E501


        :return: The length_units of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._length_units

    @length_units.setter
    def length_units(self, length_units):
        """Sets the length_units of this BTDocumentElementInfo.


        :param length_units: The length_units of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._length_units = length_units

    @property
    def angle_units(self):
        """Gets the angle_units of this BTDocumentElementInfo.  # noqa: E501


        :return: The angle_units of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._angle_units

    @angle_units.setter
    def angle_units(self, angle_units):
        """Sets the angle_units of this BTDocumentElementInfo.


        :param angle_units: The angle_units of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._angle_units = angle_units

    @property
    def mass_units(self):
        """Gets the mass_units of this BTDocumentElementInfo.  # noqa: E501


        :return: The mass_units of this BTDocumentElementInfo.  # noqa: E501
        :rtype: str
        """
        return self._mass_units

    @mass_units.setter
    def mass_units(self, mass_units):
        """Sets the mass_units of this BTDocumentElementInfo.


        :param mass_units: The mass_units of this BTDocumentElementInfo.  # noqa: E501
        :type: str
        """

        self._mass_units = mass_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTDocumentElementInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    OpenAPI spec version: 1.96
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BTVersionOrWorkspaceParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'microversion_id': 'str',
        'workspace_id': 'str',
        'version_id': 'str',
        'document_id': 'str',
        'read_only': 'bool',
        'is_release': 'bool',
        'from_history': 'bool',
        'client_interaction_mode': 'str'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'microversion_id': 'microversionId',
        'workspace_id': 'workspaceId',
        'version_id': 'versionId',
        'document_id': 'documentId',
        'read_only': 'readOnly',
        'is_release': 'isRelease',
        'from_history': 'fromHistory',
        'client_interaction_mode': 'clientInteractionMode'
    }

    def __init__(self, name=None, description=None, microversion_id=None, workspace_id=None, version_id=None, document_id=None, read_only=None, is_release=None, from_history=None, client_interaction_mode=None):  # noqa: E501
        """BTVersionOrWorkspaceParams - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._description = None
        self._microversion_id = None
        self._workspace_id = None
        self._version_id = None
        self._document_id = None
        self._read_only = None
        self._is_release = None
        self._from_history = None
        self._client_interaction_mode = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if microversion_id is not None:
            self.microversion_id = microversion_id
        if workspace_id is not None:
            self.workspace_id = workspace_id
        if version_id is not None:
            self.version_id = version_id
        if document_id is not None:
            self.document_id = document_id
        if read_only is not None:
            self.read_only = read_only
        if is_release is not None:
            self.is_release = is_release
        if from_history is not None:
            self.from_history = from_history
        if client_interaction_mode is not None:
            self.client_interaction_mode = client_interaction_mode

    @property
    def name(self):
        """Gets the name of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The name of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BTVersionOrWorkspaceParams.


        :param name: The name of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The description of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BTVersionOrWorkspaceParams.


        :param description: The description of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def microversion_id(self):
        """Gets the microversion_id of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The microversion_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._microversion_id

    @microversion_id.setter
    def microversion_id(self, microversion_id):
        """Sets the microversion_id of this BTVersionOrWorkspaceParams.


        :param microversion_id: The microversion_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._microversion_id = microversion_id

    @property
    def workspace_id(self):
        """Gets the workspace_id of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The workspace_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._workspace_id

    @workspace_id.setter
    def workspace_id(self, workspace_id):
        """Sets the workspace_id of this BTVersionOrWorkspaceParams.


        :param workspace_id: The workspace_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._workspace_id = workspace_id

    @property
    def version_id(self):
        """Gets the version_id of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The version_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this BTVersionOrWorkspaceParams.


        :param version_id: The version_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._version_id = version_id

    @property
    def document_id(self):
        """Gets the document_id of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The document_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this BTVersionOrWorkspaceParams.


        :param document_id: The document_id of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def read_only(self):
        """Gets the read_only of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The read_only of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this BTVersionOrWorkspaceParams.


        :param read_only: The read_only of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def is_release(self):
        """Gets the is_release of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The is_release of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: bool
        """
        return self._is_release

    @is_release.setter
    def is_release(self, is_release):
        """Sets the is_release of this BTVersionOrWorkspaceParams.


        :param is_release: The is_release of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: bool
        """

        self._is_release = is_release

    @property
    def from_history(self):
        """Gets the from_history of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The from_history of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: bool
        """
        return self._from_history

    @from_history.setter
    def from_history(self, from_history):
        """Sets the from_history of this BTVersionOrWorkspaceParams.


        :param from_history: The from_history of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: bool
        """

        self._from_history = from_history

    @property
    def client_interaction_mode(self):
        """Gets the client_interaction_mode of this BTVersionOrWorkspaceParams.  # noqa: E501


        :return: The client_interaction_mode of this BTVersionOrWorkspaceParams.  # noqa: E501
        :rtype: str
        """
        return self._client_interaction_mode

    @client_interaction_mode.setter
    def client_interaction_mode(self, client_interaction_mode):
        """Sets the client_interaction_mode of this BTVersionOrWorkspaceParams.


        :param client_interaction_mode: The client_interaction_mode of this BTVersionOrWorkspaceParams.  # noqa: E501
        :type: str
        """

        self._client_interaction_mode = client_interaction_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BTVersionOrWorkspaceParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
